@@ -80,7 +80,7 @@ Nova::~Nova()
 	//
 }
 
-QVariantMap Nova::getMap(void)
+QVariantMap Nova::getMap(void) const
 {
 	QVariantMap map;
 	map["designation"] = designation;
@@ -161,6 +161,26 @@ QString Nova::getInfoString(const StelCore* core, const InfoStringGroup& flags)
 	return str;
 }
 
+
+QVariantMap Nova::getInfoMap(const StelCore *core) const
+{
+	QVariantMap map = StelObject::getInfoMap(core);
+
+	map["designation"] = designation;
+	map["name"] = novaName;
+	map["nova-type"] = novaType;
+	map["max-magnitude"] = maxMagnitude;
+	map["min-magnitude"] = minMagnitude;
+	map["peakJD"] = peakJD;
+	map["m2"] = m2;
+	map["m3"] = m3;
+	map["m6"] = m6;
+	map["m9"] = m9;
+	map["distance"] = distance;
+
+	return map;
+}
+
 Vec3f Nova::getInfoColor(void) const
 {
 	return Vec3f(1.0, 1.0, 1.0);
