@@ -25,8 +25,7 @@ Ocular::Ocular()
 	  m_permanetCrosshair(false),
 	  m_appearentFOV(0.0),
 	  m_effectiveFocalLength(0.0),
-	  m_fieldStop(0.0),
-	  m_reticleFOV(0.0)
+	  m_fieldStop(0.0)
 {
 }
 
@@ -37,7 +36,7 @@ Ocular::Ocular(const QObject& other)
 	  m_effectiveFocalLength(other.property("effectiveFocalLength").toDouble()),
 	  m_fieldStop(other.property("fieldStop").toDouble()),
 	  m_name(other.property("name").toString()),
-	  m_reticleFOV(other.property("reticleFOV").toDouble())
+	  m_reticlePath(other.property("reticlePath").toString())
 {
 }
 
@@ -70,7 +69,7 @@ QMap<int, QString> Ocular::propertyMap(void)
 /* ********************************************************************* */
 double Ocular::actualFOV(const Telescope * telescope, const Lens * lens) const
 {
-	const double lens_multipler = (lens != NULL ? lens->multipler() : 1.0f);
+	const double lens_multipler = (lens != NULL ? lens->getMultipler() : 1.0f);
 	double actualFOV = 0.0;
 	if (m_binoculars) {
 		actualFOV = appearentFOV();
@@ -89,7 +88,7 @@ double Ocular::magnification(const Telescope * telescope, const Lens * lens) con
 	if (m_binoculars) {
 		magnifiction = effectiveFocalLength();
 	} else {
-		const double lens_multipler = (lens != NULL ? lens->multipler() : 1.0f);
+		const double lens_multipler = (lens != NULL ? lens->getMultipler() : 1.0f);
 		magnifiction = telescope->focalLength() * lens_multipler / effectiveFocalLength();
 	}
 	return magnifiction;
@@ -183,12 +182,12 @@ Ocular * Ocular::ocularFromSettings(const QSettings *theSettings, const int ocul
 	QString prefix = "ocular/" + QVariant(ocularIndex).toString() + "/";
 
 	ocular->setName(theSettings->value(prefix + "name", "").toString());
-	ocular->setAppearentFOV(theSettings->value(prefix + "afov", "0.0").toDouble());
-	ocular->setEffectiveFocalLength(theSettings->value(prefix + "efl", "0.0").toDouble());
-	ocular->setFieldStop(theSettings->value(prefix + "fieldStop", "0.0").toDouble());
+	ocular->setAppearentFOV(theSettings->value(prefix + "afov", 0.0).toDouble());
+	ocular->setEffectiveFocalLength(theSettings->value(prefix + "efl", 0.0).toDouble());
+	ocular->setFieldStop(theSettings->value(prefix + "fieldStop", 0.0).toDouble());
 	ocular->setBinoculars(theSettings->value(prefix + "binoculars", "false").toBool());
 	ocular->setPermanentCrosshair(theSettings->value(prefix + "permanentCrosshair", "false").toBool());
-	ocular->setReticlePath(theSettings->value(prefix + "reticlePath", "").toString());	
+	ocular->setReticlePath(theSettings->value(prefix + "reticlePath", "").toString());
 
 	if (!(ocular->appearentFOV() > 0.0 && ocular->effectiveFocalLength() > 0.0)) {
 		qWarning() << "WARNING: Invalid data for ocular. Ocular values must be positive. \n"
@@ -211,7 +210,7 @@ void Ocular::writeToSettings(QSettings * settings, const int index)
 	settings->setValue(prefix + "fieldStop", this->fieldStop());
 	settings->setValue(prefix + "binoculars", this->isBinoculars());
 	settings->setValue(prefix + "permanentCrosshair", this->hasPermanentCrosshair());
-	settings->setValue(prefix + "reticlePath", this->reticlePath());	
+	settings->setValue(prefix + "reticlePath", this->reticlePath());
 }
 
 Ocular * Ocular::ocularModel(void)
@@ -223,6 +222,6 @@ Ocular * Ocular::ocularModel(void)
 	model->setFieldStop(0);
 	model->setBinoculars(false);
 	model->setPermanentCrosshair(false);
-	model->setReticlePath("");	
+	model->setReticlePath("");
 	return model;
 }
