@@ -25,7 +25,11 @@
 #include <QDebug>
 #include <QTimer>
 
-SimbadLookupReply::SimbadLookupReply(const QString& aurl, QNetworkAccessManager* anetMgr, int delayMs) : url(aurl), reply(NULL), netMgr(anetMgr), currentStatus(SimbadLookupQuerying)
+SimbadLookupReply::SimbadLookupReply(const QString& aurl, QNetworkAccessManager* anetMgr, int delayMs)
+	: url(aurl)
+	, reply(NULL)
+	, netMgr(anetMgr)
+	, currentStatus(SimbadLookupQuerying)
 {
 	if(delayMs <= 0)
 		delayTimerCompleted();
@@ -128,8 +132,8 @@ void SimbadLookupReply::httpQueryFinished()
 				StelUtils::spheToRect(ra, dec, v);
 				line = reply->readLine();
 				line.chop(1); // Remove a line break at the end
-				line.replace("NAME " ,"");
-				resultPositions[line]=v;
+				line.replace("NAME " ,"");				
+				resultPositions[line.simplified()]=v; // Remove an extra spaces
 			}
 			line = reply->readLine();
 			line.chop(1); // Remove a line break at the end
@@ -165,8 +169,15 @@ SimbadLookupReply* SimbadSearcher::lookup(const QString& serverUrl, const QStrin
 {
 	// Create the Simbad query
 	QString url(serverUrl);
-	url += "simbad/sim-script?script=format object \"%COO(d;A D)\\n%IDLIST(1)\"\n";
-	url += QString("set epoch J2000\nset limit %1\n query id ").arg(maxNbResult);
-	url += objectName;
-	return new SimbadLookupReply(url, networkMgr, delayMs);
+	QString query = "format object \"%COO(d;A D)\\n%IDLIST(1)\"\n";
+	query += QString("set epoch J2000\nset limit %1\n query id ").arg(maxNbResult);
+	query += objectName;
+	QByteArray ba = QUrl::toPercentEncoding(query, "", "");
+
+	url += "simbad/sim-script?script=";
+	url += ba.constData();
+	if (networkMgr->networkAccessible()==QNetworkAccessManager::Accessible)
+		return new SimbadLookupReply(url, networkMgr, delayMs);
+	else
+		return NULL;
 }
