@@ -17,17 +17,21 @@
  */
 
 #include "StelAudioMgr.hpp"
+#include "StelFileMgr.hpp"
 #include <QDebug>
 #include <QDir>
 
+#ifdef ENABLE_MEDIA
+
+#include <QMediaPlayer>
+
 StelAudioMgr::StelAudioMgr()
 {
 }
 
-#ifdef HAVE_QT_PHONON
 StelAudioMgr::~StelAudioMgr()
 {
-	foreach(QString id, audioObjects.keys())
+	foreach(const QString& id, audioObjects.keys())
 	{
 		dropSound(id);
 	}
@@ -41,42 +45,65 @@ void StelAudioMgr::loadSound(const QString& filename, const QString& id)
 		dropSound(id);
 	}
 
-	Phonon::MediaObject* sound = Phonon::createPlayer(Phonon::GameCategory, Phonon::MediaSource(filename));
+	QMediaPlayer* sound = new QMediaPlayer();
+	QString path = QFileInfo(filename).absoluteFilePath();
+	sound->setMedia(QMediaContent(QUrl::fromLocalFile(path)));
 	audioObjects[id] = sound;
 }
 
 void StelAudioMgr::playSound(const QString& id)
 {
 	if (audioObjects.contains(id))
+	{
 		if (audioObjects[id]!=NULL)
 		{
 			// if already playing, stop and play from the start
-			if (audioObjects[id]->state() == Phonon::PlayingState)
+			if (audioObjects[id]->state()==QMediaPlayer::PlayingState)
 				audioObjects[id]->stop();
 
 			// otherwise just play it
 			audioObjects[id]->play();
 		}
+		else
+			qDebug() << "StelAudioMgr: Cannot play sound, " << id << "not correctly loaded.";
+	}
+	else
+		qDebug() << "StelAudioMgr: Cannot play sound, " << id << "not loaded.";
 }
 
 void StelAudioMgr::pauseSound(const QString& id)
 {
 	if (audioObjects.contains(id))
+	{
 		if (audioObjects[id]!=NULL)
 			audioObjects[id]->pause();
+		else
+			qDebug() << "StelAudioMgr: Cannot pause sound, " << id << "not correctly loaded.";
+	}
+	else
+		qDebug() << "StelAudioMgr: Cannot pause sound, " << id << "not loaded.";
 }
 
 void StelAudioMgr::stopSound(const QString& id)
 {
 	if (audioObjects.contains(id))
+	{
 		if (audioObjects[id]!=NULL)
 			audioObjects[id]->stop();
+		else
+			qDebug() << "StelAudioMgr: Cannot stop sound, " << id << "not correctly loaded.";
+	}
+	else
+		qDebug() << "StelAudioMgr: Cannot stop sound, " << id << "not loaded.";
 }
 
 void StelAudioMgr::dropSound(const QString& id)
 {
 	if (!audioObjects.contains(id))
+	{
+		qDebug() << "StelAudioMgr: Cannot drop sound, " << id << "not loaded.";
 		return;
+	}
 	if (audioObjects[id]!=NULL)
 	{
 		audioObjects[id]->stop();
@@ -85,16 +112,46 @@ void StelAudioMgr::dropSound(const QString& id)
 	}
 }
 
-#else  // HAVE_QT_PHONON
+
+qint64 StelAudioMgr::position(const QString& id)
+{
+	if (!audioObjects.contains(id))
+	{
+		qDebug() << "StelAudioMgr: Cannot report position for sound, " << id << "not loaded.";
+		return(-1);
+	}
+	if (audioObjects[id]!=NULL)
+	{
+		return audioObjects[id]->position();
+	}
+	return (-1);
+}
+
+qint64 StelAudioMgr::duration(const QString& id)
+{
+	if (!audioObjects.contains(id))
+	{
+		qDebug() << "StelAudioMgr: Cannot report duration for sound, " << id << "not loaded.";
+		return(-1);
+	}
+	if (audioObjects[id]!=NULL)
+	{
+		return audioObjects[id]->duration();
+	}
+	return (-1);
+}
+
+#else 
 void StelAudioMgr::loadSound(const QString& filename, const QString& id)
 {
 	qWarning() << "This build of Stellarium does not support sound - cannot load audio" << QDir::toNativeSeparators(filename) << id;
 }
+StelAudioMgr::StelAudioMgr() {}
 StelAudioMgr::~StelAudioMgr() {;}
 void StelAudioMgr::playSound(const QString&) {;}
 void StelAudioMgr::pauseSound(const QString&) {;}
 void StelAudioMgr::stopSound(const QString&) {;}
 void StelAudioMgr::dropSound(const QString&) {;}
-#endif // HAVE_QT_PHONON
-
-
+qint64 StelAudioMgr::position(const QString&){return -1;}
+qint64 StelAudioMgr::duration(const QString&){return -1;}
+#endif
