@@ -59,6 +59,8 @@ class StelCore : public QObject
 	Q_PROPERTY(ProjectionType currentProjectionType READ getCurrentProjectionType WRITE setCurrentProjectionType NOTIFY currentProjectionTypeChanged)
 	//! This is just another way to access the projection type, by string instead of enum
 	Q_PROPERTY(QString currentProjectionTypeKey READ getCurrentProjectionTypeKey WRITE setCurrentProjectionTypeKey NOTIFY currentProjectionTypeKeyChanged STORED false)
+	//! Read-only property returning the localized projection name
+	Q_PROPERTY(QString currentProjectionNameI18n READ getCurrentProjectionNameI18n NOTIFY currentProjectionNameI18nChanged STORED false)
 
 public:
 
@@ -75,7 +77,8 @@ public:
 							//!< The north pole follows the precession of the planet on which the observer is located.
 							//!< On Earth, this may include nutation if so configured. Has been corrected for V0.14 to really properly reflect ecliptical motion and precession (Vondrak 2011 model) and nutation.
 		FrameJ2000,				//!< Equatorial reference frame at the J2000 equinox centered on the observer. This is also the ICRS reference frame.
-		FrameGalactic				//!< Galactic reference frame centered on observer.
+		FrameGalactic,				//!< Galactic reference frame centered on observer.
+		FrameSupergalactic			//!< Supergalactic reference frame centered on observer.
 	};
 
 	//! @enum ProjectionType
@@ -136,7 +139,8 @@ public:
 		EspenakMeeusZeroMoonAccel,          //!< Espenak & Meeus (2006) algorithm for DeltaT (but without additional Lunar acceleration. FOR TESTING ONLY, NONPUBLIC)
 		Banjevic,                           //!< Banjevic (2006) algorithm for DeltaT
 		IslamSadiqQureshi,                  //!< Islam, Sadiq & Qureshi (2008 + revisited 2013) algorithm for DeltaT (6 polynomials)
-		KhalidSultanaZaidi,                 //!< M. Khalid, Mariam Sultana and Faheem Zaidi polinomial approximation of time period 1620-2013 (2014)
+		KhalidSultanaZaidi,                 //!< M. Khalid, Mariam Sultana and Faheem Zaidi polynomial approximation of time period 1620-2013 (2014)
+		StephensonMorrisonHohenkerk2016,    //!< Stephenson, Morrison, Hohenkerk (2016) RSPA paper provides spline fit to observations for -720..2016 and else parabolic fit.
 		Custom                              //!< User defined coefficients for quadratic equation for DeltaT
 	};
 
@@ -214,9 +218,21 @@ public:
 	Vec3d j2000ToAltAz(const Vec3d& v, RefractionMode refMode=RefractionAuto) const;
 	void j2000ToAltAzInPlaceNoRefraction(Vec3f* v) const {v->transfo4d(matJ2000ToAltAz);}
 	Vec3d galacticToJ2000(const Vec3d& v) const;
-	Vec3d equinoxEquToJ2000(const Vec3d& v) const;
-	Vec3d j2000ToEquinoxEqu(const Vec3d& v) const;
+	Vec3d supergalacticToJ2000(const Vec3d& v) const;
+	//! Transform position vector v from equatorial coordinates of date (which may also include atmospheric refraction) to those of J2000.
+	//! Use refMode=StelCore::RefractionOff if you don't want any atmosphere correction.
+	//! Use refMode=StelCore::RefractionOn to create observed (apparent) coordinates (which are subject to refraction).
+	//! Use refMode=StelCore::RefractionAuto to correct coordinates for refraction only when atmosphere is active.
+	Vec3d equinoxEquToJ2000(const Vec3d& v, RefractionMode refMode=RefractionAuto) const;
+	//! Use fixed matrix to allow fast transformation of positions related to the IAU constellation borders.
+	Vec3d j2000ToJ1875(const Vec3d& v) const;
+	//! Transform position vector v from equatorial coordinates J2000 to those of date (optionally corrected by refraction).
+	//! Use refMode=StelCore::RefractionOff if you don't want any atmosphere correction.
+	//! Use refMode=StelCore::RefractionOn to correct observed (apparent) coordinates (which are subject to refraction).
+	//! Use refMode=StelCore::RefractionAuto to correct coordinates for refraction only when atmosphere is active.
+	Vec3d j2000ToEquinoxEqu(const Vec3d& v, RefractionMode refMode=RefractionAuto) const;
 	Vec3d j2000ToGalactic(const Vec3d& v) const;
+	Vec3d j2000ToSupergalactic(const Vec3d& v) const;
 
 	//! Transform vector from heliocentric ecliptic coordinate to altazimuthal
 	Vec3d heliocentricEclipticToAltAz(const Vec3d& v, RefractionMode refMode=RefractionAuto) const;
@@ -249,20 +265,32 @@ public:
 	//! Get the modelview matrix for observer-centric Galactic equatorial drawing.
 	StelProjector::ModelViewTranformP getGalacticModelViewTransform(RefractionMode refMode=RefractionAuto) const;
 
+	//! Get the modelview matrix for observer-centric Supergalactic equatorial drawing.
+	StelProjector::ModelViewTranformP getSupergalacticModelViewTransform(RefractionMode refMode=RefractionAuto) const;
+
 	//! Rotation matrix from equatorial J2000 to ecliptic (VSOP87A).
 	static const Mat4d matJ2000ToVsop87;
 	//! Rotation matrix from ecliptic (VSOP87A) to equatorial J2000.
 	static const Mat4d matVsop87ToJ2000;
 	//! Rotation matrix from J2000 to Galactic reference frame, using FITS convention.
 	static const Mat4d matJ2000ToGalactic;
-	//! Rotation matrix from J2000 to Galactic reference frame, using FITS convention.
+	//! Rotation matrix from Galactic to J2000 reference frame, using FITS convention.
 	static const Mat4d matGalacticToJ2000;
+	//! Rotation matrix from J2000 to Supergalactic reference frame.
+	static const Mat4d matJ2000ToSupergalactic;
+	//! Rotation matrix from Supergalactic to J2000 reference frame.
+	static const Mat4d matSupergalacticToJ2000;
 
-	//! Return the observer heliocentric ecliptic position
+	//! Return the observer heliocentric ecliptic position (GZ: presumably J2000)
 	Vec3d getObserverHeliocentricEclipticPos() const;
 
 	//! Get the informations on the current location
 	const StelLocation& getCurrentLocation() const;
+	//! Get the UTC offset on the current location (in hours)
+	float getUTCOffset(const double JD) const;
+
+	QString getCurrentTimeZone() const;
+	void setCurrentTimeZone(const QString& tz);
 
 	const QSharedPointer<class Planet> getCurrentPlanet() const;
 
@@ -282,6 +310,7 @@ public:
 	static const double JD_HOUR;
 	static const double JD_DAY;
 	static const double ONE_OVER_JD_SECOND;
+	static const double TZ_ERA_BEGINNING;
 
 	//! Get the sidereal time shifted by the observer longitude
 	//! @return the local sidereal time in radian
@@ -332,11 +361,13 @@ public slots:
 	//! Set the current ProjectionType to use from its key
 	void setCurrentProjectionTypeKey(QString type);
 
+	QString getCurrentProjectionNameI18n() const;
+
 	//! Get the list of all the available projections
 	QStringList getAllProjectionTypeKeys() const;
 
-	//! Set the current algorithm for time correction (DeltaT)
-	void setCurrentDeltaTAlgorithm(DeltaTAlgorithm algorithm) { currentDeltaTAlgorithm=algorithm; }
+	//! Set the current algorithm and nDot used therein for time correction (DeltaT)
+	void setCurrentDeltaTAlgorithm(DeltaTAlgorithm algorithm);
 	//! Get the current algorithm for time correction (DeltaT)
 	DeltaTAlgorithm getCurrentDeltaTAlgorithm() const { return currentDeltaTAlgorithm; }
 	//! Get description of the current algorithm for time correction
@@ -383,6 +414,8 @@ public slots:
 	//! Setting to a negative value will move the visible horizon down, this may be desired esp. in cylindrical projection.
 	//! Animation is available via StelMovementMgr::moveViewport()
 	void setViewportVerticalOffset(double newOffsetPct);
+	// Set both viewport offsets. Arguments will be clamped to be inside [-50...50]. I (GZ) hope this will avoid some of the shaking.
+	void setViewportOffset(double newHorizontalOffsetPct, double newVerticalOffsetPct);
 
 	//! Can be used in specialized setups, intended e.g. for multi-projector installations with edge blending.
 	//! @param stretch [default 1] enlarge to stretch image to non-square pixels. A minimum value of 0.001 is enforced.
@@ -420,6 +453,17 @@ public slots:
 	//! It is still frequently used in the literature.
 	double getJDE() const;
 
+	//! Get solution of equation of time
+	//! Source: J. Meeus "Astronomical Algorithms" (2nd ed., with corrections as of August 10, 2009) p.183-187.
+	//! @param JDE JD in Dynamical Time (previously called Ephemeris Time)
+	//! @return time in minutes
+	double getSolutionEquationOfTime(const double JDE) const;
+
+	bool getUseDST() const;
+	void setUseDST(const bool b);
+
+	bool getUseCustomTimeZone(void) const;
+	void setUseCustomTimeZone(const bool b);
 
 	//! Set the current date in Modified Julian Day (UT).
 	//! MJD is simply JD-2400000.5, getting rid of large numbers and starting days at midnight.
@@ -428,17 +472,21 @@ public slots:
 	//! Get the current date in Modified Julian Day (UT)
 	double getMJDay() const;
 
-	//! Compute Delta-T estimation for a given date.
+	//! Compute DeltaT estimation for a given date.
 	//! DeltaT is the accumulated effect of earth's rotation slowly getting slower, mostly caused by tidal braking by the Moon.
 	//! For accurate positioning of objects in the sky, we must compute earth-based clock-dependent things like earth rotation, hour angles etc.
 	//! using plain UT, but all orbital motions or rotation of the other planets must be computed in TT, which is a regular time frame.
 	//! Also satellites are computed in the UT frame because (1) they are short-lived and (2) must follow paths over earth ground.
-	//! (Note that we make no further difference between TT and DT, those are regarded equivalent for our purpose.)
+	//! (Note that we make no further difference between TT and DT, those might differ by milliseconds at best but are regarded equivalent for our purpose.)
 	//! @param JD the date and time expressed as a Julian Day
 	//! @return DeltaT in seconds
-	//! @note Thanks to Rob van Gent which create a collection from many formulas for calculation of Delta-T: http://www.staff.science.uu.nl/~gent0113/deltat/deltat.htm
+	//! @note Thanks to Rob van Gent who created a collection from many formulas for calculation of DeltaT: http://www.staff.science.uu.nl/~gent0113/deltat/deltat.htm
 	//! @note Use this only if needed, prefer calling getDeltaT() for access to the current value.
-	double computeDeltaT(const double JD) const;
+	//! @note Up to V0.15.1, if the requested year was outside validity range, we returned zero or some useless value.
+	//!       Starting with V0.15.2 the value from the edge of the defined range is returned instead if not explicitly zero is given in the source.
+	//!       Limits can be queried with getCurrentDeltaTAlgorithmValidRangeDescription()
+
+	double computeDeltaT(const double JD);
 	//! Get current DeltaT.
 	double getDeltaT() const;
 
@@ -462,6 +510,8 @@ public slots:
 	//! Get time speed in JDay/sec
 	double getTimeRate() const;
 
+	void revertTimeDirection(void);
+
 	//! Increase the time speed
 	void increaseTimeSpeed();
 	//! Decrease the time speed
@@ -494,6 +544,8 @@ public slots:
 	//! Set the preset sky time from a QDateTime
 	void setPresetSkyTime(QDateTime dateTime);
 
+	//! Add one [Earth, solar] minute to the current simulation time.
+	void addMinute();
 	//! Add one [Earth, solar] hour to the current simulation time.
 	void addHour();
 	//! Add one [Earth, solar] day to the current simulation time.
@@ -513,6 +565,8 @@ public slots:
 	//! connected to orbital period of planets.
 	void addSiderealYears(float n=100.f);
 
+	//! Subtract one [Earth, solar] minute to the current simulation time.
+	void subtractMinute();
 	//! Subtract one [Earth, solar] hour to the current simulation time.
 	void subtractHour();
 	//! Subtract one [Earth, solar] day to the current simulation time.
@@ -609,21 +663,23 @@ public slots:
 	//! the selected object is of the correct type - i.e. a planet.
 	void moveObserverToSelected();
 
-	//! Set central year for custom equation for calculation of Delta-T
+	//! Set central year for custom equation for calculation of DeltaT
 	//! @param y the year, e.g. 1820
 	void setDeltaTCustomYear(float y) { deltaTCustomYear=y; }
-	//! Set n-dot for custom equation for calculation of Delta-T
-	//! @param y the n-dot value, e.g. -26.0
+	//! Set n-dot for custom equation for calculation of DeltaT
+	//! @param v the n-dot value, e.g. -26.0
 	void setDeltaTCustomNDot(float v) { deltaTCustomNDot=v; }
-	//! Set coefficients for custom equation for calculation of Delta-T
-	//! @param y the coefficients, e.g. -20,0,32
+	//! Set coefficients for custom equation for calculation of DeltaT
+	//! @param c the coefficients, e.g. -20,0,32
 	void setDeltaTCustomEquationCoefficients(Vec3f c) { deltaTCustomEquationCoeff=c; }
 
-	//! Get central year for custom equation for calculation of Delta-T
+	//! Get central year for custom equation for calculation of DeltaT
 	float getDeltaTCustomYear() const { return deltaTCustomYear; }
-	//! Get n-dot for custom equation for calculation of Delta-T
+	//! Get n-dot for custom equation for calculation of DeltaT
 	float getDeltaTCustomNDot() const { return deltaTCustomNDot; }
-	//! Get coefficients for custom equation for calculation of Delta-T
+	//! Get n-dot for current DeltaT algorithm
+	float getDeltaTnDot() const { return deltaTnDot; }
+	//! Get coefficients for custom equation for calculation of DeltaT
 	Vec3f getDeltaTCustomEquationCoefficients() const { return deltaTCustomEquationCoeff; }
 
 	//! initialize ephemerides calculation functions
@@ -633,9 +689,15 @@ public slots:
 	bool de431IsAvailable();            //!< true if DE431 ephemeris file has been found
 	bool de430IsActive();               //!< true if DE430 ephemeris is in use
 	bool de431IsActive();               //!< true if DE431 ephemeris is in use
-	void setDe430Active(bool status);   //!< switch DE430 use to @param status (if de430IsAvailable()) DE430 is only used if date is within range of DE430.
+	void setDe430Active(bool status);   //!< switch DE430 use to @param status (if de430IsAvailable()). DE430 is only used if date is within range of DE430.
 	void setDe431Active(bool status);   //!< switch DE431 use to @param status (if de431IsAvailable()). DE431 is only used if DE430 is not used and the date is within range of DE431.
 
+	//! Return 3-letter abbreviation of IAU constellation name for position in J2000 coordinates.
+	//! Follows 1987PASP...99..695R: Nancy Roman: Identification of a Constellation from a Position
+	//! Data file from ADC catalog VI/42 with her amendment from 1999-12-30.
+	QString getIAUConstellation(const Vec3d positionJ2000) const;
+
+
 signals:
 	//! This signal is emitted when the observer location has changed.
 	void locationChanged(StelLocation);
@@ -645,6 +707,8 @@ signals:
 	//! This happens whenever the internal jDay is changed through setJDay/setMJDay and similar,
 	//! and whenever the time rate changes.
 	void timeSyncOccurred(double jDay);
+	//! This signal is emitted when the date has changed.
+	void dateChanged();
 	//! This signal indicates a horizontal display flip
 	void flipHorzChanged(bool b);
 	//! This signal indicates a vertical display flip
@@ -657,6 +721,8 @@ signals:
 	void currentProjectionTypeChanged(StelCore::ProjectionType newType);
 	//! Emitted whenever the projection type changes
 	void currentProjectionTypeKeyChanged(const QString& newValue);
+	//! Emitted whenever the projection type changes
+	void currentProjectionNameI18nChanged(const QString& newValue);
 
 private:
 	StelToneReproducer* toneReproducer;		// Tones conversion between stellarium world and display device
@@ -691,8 +757,10 @@ private:
 	Mat4d matHeliocentricEclipticToEquinoxEqu; // Transform from heliocentric ecliptic Cartesian (VSOP87A) to earth equatorial coordinate
 	Mat4d matEquinoxEquToJ2000;                // For Earth, this is almost the inverse precession matrix, =Rz(VSOPbias)Rx(eps0)Rz(-psiA)Rx(-omA)Rz(chiA)
 	Mat4d matJ2000ToEquinoxEqu;                // precession matrix
+	static Mat4d matJ2000ToJ1875;              // Precession matrix for IAU constellation lookup.
 
 	Mat4d matJ2000ToAltAz;
+	Mat4d matAltAzToJ2000;
 
 	Mat4d matAltAzModelView;           // Modelview matrix for observer-centric altazimuthal drawing
 	Mat4d invertMatAltAzModelView;     // Inverted modelview matrix for observer-centric altazimuthal drawing
@@ -711,17 +779,26 @@ private:
 	double timeSpeed;           // Positive : forward, Negative : Backward, 1 = 1sec/sec
 	//double JDay;              // Current time in Julian day. IN V0.12 TO V0.14, this was JD in TT, and all places where UT was required had to subtract getDeltaT() explicitly.
 	QPair<double,double> JD;    // From 0.14 on: JD.first=JD_UT, JD.second=DeltaT=TT-UT. To gain JD_TT, compute JDE=JD.first+JD.second or better just call getJDE()
-				// Use is best with calls getJD()/setJD() and getJDE()/setJDE() to explicitly state which flavour of JD you need.
+				    // Use is best with calls getJD()/setJD() and getJDE()/setJDE() to explicitly state which flavour of JD you need.
 	double presetSkyTime;
 	QTime initTodayTime;
 	QString startupTimeMode;
 	double milliSecondsOfLastJDUpdate;    // Time in seconds when the time rate or time last changed
 	double jdOfLastJDUpdate;         // JD when the time rate or time last changed
 
-	// Variables for custom equation of Delta-T
+	QString currentTimeZone;	
+	bool flagUseDST;
+	bool flagUseCTZ; // custom time zone
+
+	// Variables for equations of DeltaT
 	Vec3f deltaTCustomEquationCoeff;
 	float deltaTCustomNDot;
 	float deltaTCustomYear;
+	float deltaTnDot; // The currently applied nDot correction. (different per algorithm, and displayed in status line.)
+	bool  deltaTdontUseMoon; // true if the currenctly selected algorithm does not do a lunar correction (?????)
+	double (*deltaTfunc)(const double JD); // This is a function pointer which must be set to a function which computes DeltaT(JD).
+	int deltaTstart;   // begin year of validity range for the selected DeltaT algorithm. (SET INT_MIN to mark infinite)
+	int deltaTfinish;  // end   year of validity range for the selected DeltaT algorithm. (Set INT_MAX to mark infinite)
 
 	// Variables for DE430/431 ephem calculation
 	bool de430Available; // ephem file found
