@@ -58,17 +58,17 @@ public:
 		HourAngle		= 0x00000200, //!< The hour angle + DE (of date)
 		AbsoluteMagnitude	= 0x00000400, //!< The absolute magnitude
 		GalacticCoord		= 0x00000800, //!< The galactic position
-		ObjectType		= 0x00001000, //!< The type of the object (star, planet, etc.)
-		EclipticCoord		= 0x00002000, //!< The ecliptic position
-		EclipticCoordXYZ	= 0x00004000, //!< The ecliptic position, XYZ of VSOP87A (used mainly for debugging, not public)
-		NoFont			= 0x00008000,
-		PlainText		= 0x00010000,  //!< Strip HTML tags from output
+		SupergalacticCoord	= 0x00001000, //!< The supergalactic position
+		ObjectType		= 0x00002000, //!< The type of the object (star, planet, etc.)
+		EclipticCoordJ2000	= 0x00004000, //!< The ecliptic position (J2000.0 ref) [+ XYZ of VSOP87A (used mainly for debugging, not public)]
+		EclipticCoordOfDate	= 0x00008000, //!< The ecliptic position (of date)
+		IAUConstellation        = 0x00010000, //!< Three-letter constellation code (And, Boo, Cas, ...)
+		SiderealTime		= 0x00020000, //!< Mean and Apparent Sidereal Time
+		NoFont			= 0x00040000,
+		PlainText		= 0x00080000,  //!< Strip HTML tags from output
 // TODO GZ
 //		RaDecJ2000Planetocentric  = 0x00020000, //!< The planetocentric equatorial position (J2000 ref) [Mostly to compare with almanacs]
 //		RaDecOfDatePlanetocentric = 0x00040000  //!< The planetocentric equatorial position (of date)
-//		// and split Ecliptical into
-//		EclipticCoordJ2000	= 0x00002000, //!< The ecliptic position w.r.t. ecliptic of eq.J2000.0
-//		EclipticCoordOfDate	= 0x00002000, //!< The ecliptic position w.r.t. ecliptic of eq. of date
 
 
 	};
@@ -76,7 +76,8 @@ public:
 
 	//! A pre-defined set of specifiers for the getInfoString flags argument to getInfoString
 	static const InfoStringGroupFlags AllInfo = (InfoStringGroupFlags)(Name|CatalogNumber|Magnitude|RaDecJ2000|RaDecOfDate|AltAzi|Distance|Size|Extra|HourAngle|
-									   AbsoluteMagnitude|GalacticCoord|ObjectType|EclipticCoord|EclipticCoordXYZ);
+									   AbsoluteMagnitude|GalacticCoord|SupergalacticCoord|ObjectType|EclipticCoordJ2000|
+									   EclipticCoordOfDate|IAUConstellation|SiderealTime);
 	//! A pre-defined set of specifiers for the getInfoString flags argument to getInfoString
 	static const InfoStringGroupFlags ShortInfo = (InfoStringGroupFlags)(Name|CatalogNumber|Magnitude|RaDecJ2000);
 
@@ -98,6 +99,36 @@ public:
 	//! @return an HTML string containing information about the StelObject.
 	virtual QString getInfoString(const StelCore *core, const InfoStringGroup& flags=StelObject::AllInfo) const = 0;
 
+	//! Return a key/value map with data about an object's position, magnitude and so on. Useful in a context like scripting.
+	//! Derived objects can add their own special information tags.
+	//! @param core the current StelCore
+	//! @return a map of object data.  Keys:
+	//! - altitude : apparent altitude angle in decimal degrees
+	//! - azimuth : apparent azimuth angle in decimal degrees
+	//! - altitude-geometric : geometric altitude angle in decimal degrees
+	//! - azimuth-geometric : geometric azimuth angle in decimal degrees
+	//! - ra : right ascension angle (current date frame) in decimal degrees
+	//! - dec : declination angle (current date frame) in decimal degrees
+	//! - raJ2000 : right ascension angle (J2000 frame) in decimal degrees
+	//! - decJ2000 : declination angle (J2000 frame) in decimal degrees
+	//! - glong : galactic longitude in decimal degrees
+	//! - glat : galactic latitude in decimal degrees
+	//! - sglong : supergalactic longitude in decimal degrees
+	//! - sglat : supergalactic latitude in decimal degrees
+	//! - elong : ecliptic longitude in decimal degrees (on Earth only!)
+	//! - elat : ecliptic latitude in decimal degrees (on Earth only!)
+	//! - elongJ2000 : ecliptic longitude (Earth's J2000 frame) in decimal degrees
+	//! - elatJ2000 : ecliptic latitude (Earth's J2000 frame) in decimal degrees
+	//! - vmag : visual magnitude
+	//! - vmage : visual magnitude (after atmospheric extinction)
+	//! - size: angular size in radians
+	//! - size-dd : angular size in decimal degrees
+	//! - size-deg : angular size in decimal degrees (formatted string)
+	//! - size-dms : angular size in DMS format
+	//! - name : english name of the object
+	//! - localized-name : localized name
+	virtual QVariantMap getInfoMap(const StelCore *core) const;
+
 	//! Return object's type. It should be the name of the class.
 	virtual QString getType() const = 0;
 
@@ -111,13 +142,20 @@ public:
 	virtual Vec3d getJ2000EquatorialPos(const StelCore* core) const = 0;
 
 	//! Get observer-centered equatorial coordinate at the current equinox
-	//! The frame has it's Z axis at the planet's current rotation axis
+	//! The frame has its Z axis at the planet's current rotation axis
 	//! At time 2000-01-01 this frame is almost the same as J2000, but ONLY if the observer is on earth
 	Vec3d getEquinoxEquatorialPos(const StelCore* core) const;
+	//! Like getEquinoxEquatorialPos(core), but always adds refraction correction to the position.
+	Vec3d getEquinoxEquatorialPosApparent(const StelCore* core) const;
+	//! Like getEquinoxEquatorialPos(core), but adds refraction correction to the position if atmosphere is active.
+	Vec3d getEquinoxEquatorialPosAuto(const StelCore* core) const;
 
 	//! Get observer-centered galactic coordinates
 	Vec3d getGalacticPos(const StelCore* core) const;
 
+	//! Get observer-centered supergalactic coordinates
+	Vec3d getSupergalacticPos(const StelCore* core) const;
+
 	//! Get observer-centered hour angle + declination (at current equinox)
 	//! It is the geometric position, i.e. without taking refraction effect into account.
 	//! The frame has its Z axis at the planet's current rotation axis
@@ -130,17 +168,17 @@ public:
 
 	//! Get observer-centered alt/az position
 	//! It is the geometric position, i.e. without taking refraction effect into account.
-	//! The frame has it's Z axis at the zenith
+	//! The frame has its Z axis at the zenith
 	Vec3d getAltAzPosGeometric(const StelCore* core) const;
 
 	//! Get observer-centered alt/az position
 	//! It is the apparent position, i.e. taking the refraction effect into account.
-	//! The frame has it's Z axis at the zenith
+	//! The frame has its Z axis at the zenith
 	Vec3d getAltAzPosApparent(const StelCore* core) const;
 
 	//! Get observer-centered alt/az position
 	//! It is the automatic position, i.e. taking the refraction effect into account if atmosphere is on.
-	//! The frame has it's Z axis at the zenith
+	//! The frame has its Z axis at the zenith
 	Vec3d getAltAzPosAuto(const StelCore* core) const;
 
 	//! Return object's apparent V magnitude as seen from observer, without including extinction.
