@@ -61,24 +61,18 @@ MinorPlanet::MinorPlanet(const QString& englishName,
 		  hidden,
 		  false, //No atmosphere
 		  true,  //Halo
-		  pTypeStr)
+		  pTypeStr),
+	minorPlanetNumber(0),
+	absoluteMagnitude(0.0f),
+	slopeParameter(-1.0f), //== mark as uninitialized: used in getVMagnitude()
+	semiMajorAxis(0.),
+	nameIsProvisionalDesignation(false),
+	properName(englishName)
 {
-	texMapName = atexMapName;
-	lastOrbitJDE =0;
-	deltaJDE = StelCore::JD_SECOND;
-	orbitCached = 0;
-	closeOrbit = acloseOrbit;
-	semiMajorAxis = 0.;
-
 	eclipticPos=Vec3d(0.,0.,0.);
 	rotLocalToParent = Mat4d::identity();
 	texMap = StelApp::getInstance().getTextureManager().createTextureThread(StelFileMgr::getInstallationDir()+"/textures/"+texMapName, StelTexture::StelTextureParams(true, GL_LINEAR, GL_REPEAT));
 
-	//MinorPlanet specific members
-	minorPlanetNumber = 0;
-	absoluteMagnitude = 0;
-	slopeParameter = -1;//== uninitialized: used in getVMagnitude()	
-
 	//TODO: Fix the name
 	// - Detect numeric prefix and set number if any
 	// - detect provisional designation
@@ -117,21 +111,14 @@ MinorPlanet::MinorPlanet(const QString& englishName,
 	//Try to detect a naming conflict
 	if (englishName.endsWith('*'))
 		properName = englishName.left(englishName.count() - 1);
-	else
-		properName = englishName;
 
-	//Try to detect provisional designation
-	nameIsProvisionalDesignation = false;
+	//Try to detect provisional designation	
 	QString provisionalDesignation = renderProvisionalDesignationinHtml(englishName);
 	if (!provisionalDesignation.isEmpty())
 	{
 		nameIsProvisionalDesignation = true;
 		provisionalDesignationHtml = provisionalDesignation;
 	}
-
-	nameI18 = englishName;
-
-	flagLabels = true;
 }
 
 MinorPlanet::~MinorPlanet()
@@ -290,10 +277,27 @@ QString MinorPlanet::getInfoString(const StelCore *core, const InfoStringGroup &
 
 	// If semi-major axis not zero then calculate and display orbital period for asteroid in days
 	double siderealPeriod = getSiderealPeriod();
-	if ((flags&Extra) && (siderealPeriod>0))
+	if (flags&Extra)
 	{
-		// TRANSLATORS: Sidereal (orbital) period for solar system bodies in days and in Julian years (symbol: a)
-		oss << q_("Sidereal period: %1 days (%2 a)").arg(QString::number(siderealPeriod, 'f', 2)).arg(QString::number(siderealPeriod/365.25, 'f', 3)) << "<br>";
+		if (siderealPeriod>0)
+		{
+			// TRANSLATORS: Sidereal (orbital) period for solar system bodies in days and in Julian years (symbol: a)
+			oss << q_("Sidereal period: %1 days (%2 a)").arg(QString::number(siderealPeriod, 'f', 2)).arg(QString::number(siderealPeriod/365.25, 'f', 3)) << "<br>";
+		}
+
+		const Vec3d& observerHelioPos = core->getObserverHeliocentricEclipticPos();
+		const double elongation = getElongation(observerHelioPos);
+
+		if (withDecimalDegree)
+		{
+			oss << QString(q_("Phase Angle: %1")).arg(StelUtils::radToDecDegStr(getPhaseAngle(observerHelioPos),4,false,true)) << "<br>";
+			oss << QString(q_("Elongation: %1")).arg(StelUtils::radToDecDegStr(elongation,4,false,true)) << "<br>";
+		}
+		else
+		{
+			oss << QString(q_("Phase Angle: %1")).arg(StelUtils::radToDmsStr(getPhaseAngle(observerHelioPos), true)) << "<br>";
+			oss << QString(q_("Elongation: %1")).arg(StelUtils::radToDmsStr(elongation, true)) << "<br>";
+		}
 	}
 
 	postProcessInfoString(str, flags);
