@@ -40,6 +40,7 @@ friend class NebulaMgr;
 	Q_GADGET
 	Q_FLAGS(CatalogGroup)
 	Q_FLAGS(TypeGroup)
+	Q_ENUMS(NebulaType)
 public:
 	enum CatalogGroupFlags
 	{
@@ -80,62 +81,6 @@ public:
 	static const CatalogGroupFlags AllCatalogs = (CatalogGroupFlags)(CatNGC|CatIC|CatM|CatC|CatB|CatSh2|CatLBN|CatLDN|CatRCW|CatVdB|CatCr|CatMel|CatPGC|CatUGC|CatCed);
 	static const TypeGroupFlags AllTypes = (TypeGroupFlags)(TypeGalaxies|TypeActiveGalaxies|TypeInteractingGalaxies|TypeStarClusters|TypeHydrogenRegions|TypeBrightNebulae|TypeDarkNebulae|TypePlanetaryNebulae|TypeSupernovaRemnants|TypeOther);
 
-	Nebula();
-	~Nebula();
-
-	//! Nebula support the following InfoStringGroup flags:
-	//! - Name
-	//! - CatalogNumber
-	//! - Magnitude
-	//! - RaDec
-	//! - AltAzi
-	//! - Distance
-	//! - Size
-	//! - Extra (contains the Nebula type, which might be "Galaxy", "Cluster" or similar)
-	//! - PlainText
-	//! @param core the StelCore object
-	//! @param flags a set of InfoStringGroup items to include in the return value.
-	//! @return a QString containing an HMTL encoded description of the Nebula.
-	virtual QString getInfoString(const StelCore *core, const InfoStringGroup& flags) const;
-	virtual QString getType() const {return "Nebula";}
-	virtual Vec3d getJ2000EquatorialPos(const StelCore*) const {return XYZ;}
-	virtual double getCloseViewFov(const StelCore* core = NULL) const;
-	virtual float getVMagnitude(const StelCore* core) const;
-	virtual float getSelectPriority(const StelCore* core) const;
-	virtual Vec3f getInfoColor() const;
-	virtual QString getNameI18n() const {return nameI18;}
-	virtual QString getEnglishName() const {return englishName;}
-	virtual double getAngularSize(const StelCore*) const;
-	virtual SphericalRegionP getRegion() const {return pointRegion;}
-
-	// Methods specific to Nebula
-	void setLabelColor(const Vec3f& v) {labelColor = v;}
-	void setCircleColor(const Vec3f& v) {circleColor = v;}
-
-	//! Get the printable nebula Type.
-	//! @return the nebula type code.
-	QString getTypeString() const;
-
-	//! Get the printable morphological nebula Type.
-	//! @return the nebula morphological type string.
-	QString getMorphologicalTypeString() const;
-
-	float getSurfaceBrightness(const StelCore* core) const;
-	float getSurfaceBrightnessWithExtinction(const StelCore* core) const;
-
-	//! Get the surface area.
-	//! @return surface area in square degrees.
-	float getSurfaceArea(void) const;
-
-	void setProperName(QString name) { englishName = name; }
-
-	//! Get designation for DSO (with priority: M, C, NGC, IC, B, Sh2, VdB, RCW, LDN, LBN, Cr, Mel, PGC, UGC, Ced)
-	//! @return a designation
-	QString getDSODesignation();
-
-private:
-	friend struct DrawNebulaFuncObject;
-	
 	//! @enum NebulaType Nebula types
 	enum NebulaType
 	{
@@ -156,7 +101,7 @@ private:
 		NebBn		= 14,	//!< Bipolar nebula
 		NebEn		= 15,	//!< Emission nebula
 		NebCn		= 16,	//!< Cluster associated with nebulosity
-		NebHII		= 17,	//!< HII Region		
+		NebHII		= 17,	//!< HII Region
 		NebSNR		= 18,	//!< Supernova remnant
 		NebISM		= 19,	//!< Interstellar matter
 		NebEMO		= 20,	//!< Emission object
@@ -171,8 +116,84 @@ private:
 		NebUnknown	= 29	//!< Unknown type, catalog errors, "Unidentified Southern Objects" etc.
 	};
 
+	Nebula();
+	~Nebula();
+
+	//! Nebula support the following InfoStringGroup flags:
+	//! - Name
+	//! - CatalogNumber
+	//! - Magnitude
+	//! - RaDec
+	//! - AltAzi
+	//! - Distance
+	//! - Size
+	//! - Extra (contains the Nebula type, which might be "Galaxy", "Cluster" or similar)
+	//! - PlainText
+	//! @param core the StelCore object
+	//! @param flags a set of InfoStringGroup items to include in the return value.
+	//! @return a QString containing an HMTL encoded description of the Nebula.
+	virtual QString getInfoString(const StelCore *core, const InfoStringGroup& flags) const;
+	//! In addition to the entries from StelObject::getInfoMap(), Nebula objects provide
+	//! - bmag (photometric B magnitude. 99 if unknown)
+	//! - morpho (longish description; translated!)
+	//! - surface-brightness
+	//! A few entries are optional
+	//! - bV (B-V index)
+	//! - redshift
+	virtual QVariantMap getInfoMap(const StelCore *core) const;
+	virtual QString getType() const {return "Nebula";}
+	virtual Vec3d getJ2000EquatorialPos(const StelCore*) const {return XYZ;}
+	virtual double getCloseViewFov(const StelCore* core = NULL) const;
+	virtual float getVMagnitude(const StelCore* core) const;
+	virtual float getSelectPriority(const StelCore* core) const;
+	virtual Vec3f getInfoColor() const;
+	virtual QString getNameI18n() const {return nameI18;}
+	virtual QString getEnglishName() const {return englishName;}
+	QString getEnglishAliases() const;
+	QString getI18nAliases() const;
+	virtual double getAngularSize(const StelCore*) const;
+	virtual SphericalRegionP getRegion() const {return pointRegion;}
+
+	// Methods specific to Nebula
+	void setLabelColor(const Vec3f& v) {labelColor = v;}
+	void setCircleColor(const Vec3f& v) {circleColor = v;}
+
+	//! Get the printable nebula Type.
+	//! @return the nebula type code.
+	QString getTypeString() const;
+
+	NebulaType getDSOType() const {return nType;}
+
+	//! Get the printable morphological nebula Type.
+	//! @return the nebula morphological type string.
+	QString getMorphologicalTypeString() const;
+
+	float getSurfaceBrightness(const StelCore* core) const;
+	float getSurfaceBrightnessWithExtinction(const StelCore* core) const;
+
+	//! Get the surface area.
+	//! @return surface area in square degrees.
+	float getSurfaceArea(void) const;
+
+	void setProperName(QString name) { englishName = name; }
+	void addNameAlias(QString name) { englishAliases.append(name); }
+	void removeAllNames() { englishName=""; englishAliases.clear(); }
+
+	//! Get designation for DSO (with priority: M, C, NGC, IC, B, Sh2, VdB, RCW, LDN, LBN, Cr, Mel, PGC, UGC, Ced)
+	//! @return a designation
+	QString getDSODesignation();
+
+private:
+	friend struct DrawNebulaFuncObject;
+
 	//! Translate nebula name using the passed translator
-	void translateName(const StelTranslator& trans) {nameI18 = trans.qtranslate(englishName);}
+	void translateName(const StelTranslator& trans)
+	{
+		nameI18 = trans.qtranslate(englishName);
+		nameI18Aliases.clear();
+		foreach(QString alias, englishAliases)
+			nameI18Aliases.append(trans.qtranslate(alias));
+	}
 
 	void readDSO(QDataStream& in);
 
@@ -202,7 +223,9 @@ private:
 	unsigned int UGC_nb;            // UGC number (The Uppsala General Catalogue of Galaxies)
 	QString Ced_nb;			// Ced number (Cederblad Catalog of bright diffuse Galactic nebulae)	
 	QString englishName;            // English name
+	QStringList englishAliases;	// English aliases
 	QString nameI18;                // Nebula name
+	QStringList nameI18Aliases;     // Nebula aliases
 	QString mTypeString;		// Morphological type of object (as string)	
 	float bMag;                     // B magnitude
 	float vMag;                     // V magnitude. For Dark Nebulae, opacity is stored here.	
