@@ -69,7 +69,7 @@ SolarSystem::SolarSystem()
 	, flagLightTravelTime(true)
 	, flagShow(false)
 	, flagPointer(false)
-	, flagNativeNames(false)
+	, flagNativePlanetNames(false)
 	, flagTranslatedNames(false)
 	, flagIsolatedTrails(true)
 	, flagIsolatedOrbits(true)
@@ -143,7 +143,7 @@ void SolarSystem::init()
 
 	// Compute position and matrix of sun and all the satellites (ie planets)
 	// for the first initialization Q_ASSERT that center is sun center (only impacts on light speed correction)	
-	computePositions(StelUtils::getJDFromSystem());
+	computePositions(StelApp::getInstance().getCore()->getJDE());
 
 	setSelected("");	// Fix a bug on macosX! Thanks Fumio!
 	setFlagMoonScale(conf->value("viewing/flag_moon_scaled", conf->value("viewing/flag_init_moon_scaled", "false").toBool()).toBool());  // name change
@@ -158,11 +158,12 @@ void SolarSystem::init()
 	// Set the algorithm from Astronomical Almanac for computation of apparent magnitudes for
 	// planets in case  observer on the Earth by default
 	setApparentMagnitudeAlgorithmOnEarth(conf->value("astro/apparent_magnitude_algorithm", "Harris").toString());
-	setFlagNativeNames(conf->value("viewing/flag_planets_native_names", true).toBool());
+	setFlagNativePlanetNames(conf->value("viewing/flag_planets_native_names", true).toBool());
 	// Is enabled the showing of isolated trails for selected objects only?
 	setFlagIsolatedTrails(conf->value("viewing/flag_isolated_trails", true).toBool());
 	setFlagIsolatedOrbits(conf->value("viewing/flag_isolated_orbits", true).toBool());
 	setFlagPermanentOrbits(conf->value("astro/flag_permanent_orbits", false).toBool());
+	setOrbitColorStyle(conf->value("astro/planets_orbits_color_style", "one_color").toString());
 
 	setFlagEphemerisMarkers(conf->value("astro/flag_ephemeris_markers", true).toBool());
 	setFlagEphemerisDates(conf->value("astro/flag_ephemeris_dates", false).toBool());
@@ -176,7 +177,25 @@ void SolarSystem::init()
 	// Load colors from config file
 	QString defaultColor = conf->value("color/default_color").toString();
 	setLabelsColor(StelUtils::strToVec3f(conf->value("color/planet_names_color", defaultColor).toString()));
-	setOrbitsColor(StelUtils::strToVec3f(conf->value("color/planet_orbits_color", defaultColor).toString()));
+	setOrbitsColor(StelUtils::strToVec3f(conf->value("color/sso_orbits_color", defaultColor).toString()));
+	setMajorPlanetsOrbitsColor(StelUtils::strToVec3f(conf->value("color/major_planet_orbits_color", "0.7,0.2,0.2").toString()));
+	setMoonsOrbitsColor(StelUtils::strToVec3f(conf->value("color/moon_orbits_color", "0.7,0.2,0.2").toString()));
+	setMinorPlanetsOrbitsColor(StelUtils::strToVec3f(conf->value("color/minor_planet_orbits_color", "0.7,0.5,0.5").toString()));
+	setDwarfPlanetsOrbitsColor(StelUtils::strToVec3f(conf->value("color/dwarf_planet_orbits_color", "0.7,0.5,0.5").toString()));
+	setCubewanosOrbitsColor(StelUtils::strToVec3f(conf->value("color/cubewano_orbits_color", "0.7,0.5,0.5").toString()));
+	setPlutinosOrbitsColor(StelUtils::strToVec3f(conf->value("color/plutino_orbits_color", "0.7,0.5,0.5").toString()));
+	setScatteredDiskObjectsOrbitsColor(StelUtils::strToVec3f(conf->value("color/sdo_orbits_color", "0.7,0.5,0.5").toString()));
+	setOortCloudObjectsOrbitsColor(StelUtils::strToVec3f(conf->value("color/oco_orbits_color", "0.7,0.5,0.5").toString()));
+	setCometsOrbitsColor(StelUtils::strToVec3f(conf->value("color/comet_orbits_color", "0.7,0.8,0.8").toString()));
+	setSednoidsOrbitsColor(StelUtils::strToVec3f(conf->value("color/sednoid_orbits_color", "0.7,0.5,0.5").toString()));
+	setMercuryOrbitColor(StelUtils::strToVec3f(conf->value("color/mercury_orbit_color", "0.5,0.5,0.5").toString()));
+	setVenusOrbitColor(StelUtils::strToVec3f(conf->value("color/venus_orbit_color", "0.9,0.9,0.7").toString()));
+	setEarthOrbitColor(StelUtils::strToVec3f(conf->value("color/earth_orbit_color", "0.0,0.0,1.0").toString()));
+	setMarsOrbitColor(StelUtils::strToVec3f(conf->value("color/mars_orbit_color", "0.8,0.4,0.1").toString()));
+	setJupiterOrbitColor(StelUtils::strToVec3f(conf->value("color/jupiter_orbit_color", "1.0,0.6,0.0").toString()));
+	setSaturnOrbitColor(StelUtils::strToVec3f(conf->value("color/saturn_orbit_color", "1.0,0.8,0.0").toString()));
+	setUranusOrbitColor(StelUtils::strToVec3f(conf->value("color/uranus_orbit_color", "0.0,0.7,1.0").toString()));
+	setNeptuneOrbitColor(StelUtils::strToVec3f(conf->value("color/neptune_orbit_color", "0.0,0.3,1.0").toString()));
 	setTrailsColor(StelUtils::strToVec3f(conf->value("color/object_trails_color", defaultColor).toString()));
 	setPointerColor(StelUtils::strToVec3f(conf->value("color/planet_pointers_color", "1.0,0.3,0.3").toString()));
 
@@ -187,7 +206,7 @@ void SolarSystem::init()
 	StelObjectMgr *objectManager = GETSTELMODULE(StelObjectMgr);
 	objectManager->registerStelObjectMgr(this);
 	connect(objectManager, SIGNAL(selectedObjectChanged(StelModule::StelModuleSelectAction)),
-			this, SLOT(selectedObjectChange(StelModule::StelModuleSelectAction)));
+		this, SLOT(selectedObjectChange(StelModule::StelModuleSelectAction)));
 
 	texPointer = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/pointeur4.png");
 	texCircle = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/neb.png");	// Load circle texture
@@ -204,8 +223,8 @@ void SolarSystem::init()
 	addAction("actionShow_Planets_Trails", displayGroup, N_("Planet trails"), "trailsDisplayed", "Shift+T");
 	//there is a small discrepancy in the GUI: "Show planet markers" actually means show planet hints
 	addAction("actionShow_Planets_Hints", displayGroup, N_("Planet markers"), "flagHints", "Ctrl+P");
-	//addAction("actionShow_Planets_Markers", displayGroup, N_("Planet selection marker"), "markersDisplayed", "Ctrl+Shift+P");
-	addAction("actionShow_Skyculture_Nativenames", displayGroup, N_("Native planet names (from starlore)"), "flagNativeNames", "Ctrl+Shift+N");
+	addAction("actionShow_Planets_Pointers", displayGroup, N_("Planet selection marker"), "flagPointer", "Ctrl+Shift+P");
+	addAction("actionShow_Skyculture_NativePlanetNames", displayGroup, N_("Native planet names (from starlore)"), "flagNativePlanetNames", "Ctrl+Shift+N");
 }
 
 void SolarSystem::deinit()
@@ -337,9 +356,7 @@ void SolarSystem::drawPointer(const StelCore* core)
 
 		texPointer->bind();
 
-		sPainter.enableTexture2d(true);
-		glEnable(GL_BLEND);
-		glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA); // Normal transparency mode
+		sPainter.setBlending(true);
 
 		size*=0.5;
 		const float angleBase = StelApp::getInstance().getAnimationTime() * 10;
@@ -850,7 +867,7 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 
 		if (posfunc==NULL)
 		{
-			qWarning() << "ERROR : can't find posfunc " << funcName << " for " << englishName;
+			qCritical() << "ERROR : can't find posfunc " << funcName << " for " << englishName;
 			exit(-1);
 		}
 
@@ -976,6 +993,7 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 					       pd.value(secname+"/atmosphere", false).toBool(),
 					       pd.value(secname+"/halo", 0).toBool(),
 					       type));
+			p->absoluteMagnitude = pd.value(secname+"/absolute_magnitude", -99.).toDouble();
 		}
 
 
@@ -1177,9 +1195,7 @@ void SolarSystem::draw(StelCore* core)
 				size = 4.f;
 			}
 
-			glEnable(GL_BLEND);
-			sPainter.enableTexture2d(true);
-			glBlendFunc(GL_ONE, GL_ONE);
+			sPainter.setBlending(true, GL_ONE, GL_ONE);
 
 			texCircle->bind();
 			sPainter.drawSprite2dMode(AstroCalcDialog::EphemerisListJ2000[i], size);
@@ -1273,6 +1289,24 @@ float SolarSystem::getPhaseForPlanet(QString planetName) const
 	return r;
 }
 
+QStringList SolarSystem::getObjectsList(QString objType) const
+{
+	QStringList r;
+	if (objType.toLower()=="all")
+	{
+		r = listAllObjects(true);
+		// Remove the Sun
+		r.removeOne("Sun");
+		// Remove special objects
+		r.removeOne("Solar System Observer");
+		r.removeOne("Earth Observer");
+	}
+	else
+		r = listAllObjectsByType(objType, true);
+
+	return r;
+}
+
 // Search if any Planet is close to position given in earth equatorial position and return the distance
 StelObjectP SolarSystem::search(Vec3d pos, const StelCore* core) const
 {
@@ -1307,7 +1341,7 @@ QList<StelObjectP> SolarSystem::searchAround(const Vec3d& vv, double limitFov, c
 	if (!getFlagPlanets())
 		return result;
 
-	Vec3d v = core->j2000ToEquinoxEqu(vv);
+	Vec3d v = core->j2000ToEquinoxEqu(vv, StelCore::RefractionOff);
 	v.normalize();
 	double cosLimFov = std::cos(limitFov * M_PI/180.);
 	Vec3d equPos;
@@ -1396,6 +1430,7 @@ bool SolarSystem::getFlagLabels() const
 
 void SolarSystem::setFlagOrbits(bool b)
 {
+	bool old = flagOrbits;
 	flagOrbits = b;
 	if (!b || !selected || selected==sun)
 	{
@@ -1424,7 +1459,8 @@ void SolarSystem::setFlagOrbits(bool b)
 				p->setFlagOrbits(false);
 		}
 	}
-	emit flagOrbitsChanged(b);
+	if(old != flagOrbits)
+		emit flagOrbitsChanged(flagOrbits);
 }
 
 void SolarSystem::setFlagLightTravelTime(bool b)
@@ -1586,24 +1622,24 @@ bool SolarSystem::getFlagEphemerisDates() const
 	return ephemerisDatesDisplayed;
 }
 
-void SolarSystem::setFlagNativeNames(bool b)
+void SolarSystem::setFlagNativePlanetNames(bool b)
 {
-	if (b!=flagNativeNames)
+	if (b!=flagNativePlanetNames)
 	{
-		flagNativeNames=b;
+		flagNativePlanetNames=b;
 		foreach (const PlanetP& p, systemPlanets)
 		{
 			if (p->getPlanetType()==Planet::isPlanet || p->getPlanetType()==Planet::isMoon || p->getPlanetType()==Planet::isStar)
-				p->setFlagNativeName(flagNativeNames);
+				p->setFlagNativeName(flagNativePlanetNames);
 		}
 		updateI18n();
-		emit flagNativeNamesChanged(b);
+		emit flagNativePlanetNamesChanged(b);
 	}
 }
 
-bool SolarSystem::getFlagNativeNames() const
+bool SolarSystem::getFlagNativePlanetNames() const
 {
-	return flagNativeNames;
+	return flagNativePlanetNames;
 }
 
 void SolarSystem::setFlagTranslatedNames(bool b)
@@ -1656,12 +1692,206 @@ bool SolarSystem::getFlagIsolatedOrbits() const
 
 
 // Set/Get planets names color
-void SolarSystem::setLabelsColor(const Vec3f& c) {Planet::setLabelColor(c);}
-const Vec3f& SolarSystem::getLabelsColor(void) const {return Planet::getLabelColor();}
+void SolarSystem::setLabelsColor(const Vec3f& c)
+{
+	Planet::setLabelColor(c);
+}
+
+const Vec3f& SolarSystem::getLabelsColor(void) const
+{
+	return Planet::getLabelColor();
+}
 
 // Set/Get orbits lines color
-void SolarSystem::setOrbitsColor(const Vec3f& c) {Planet::setOrbitColor(c);}
-Vec3f SolarSystem::getOrbitsColor(void) const {return Planet::getOrbitColor();}
+void SolarSystem::setOrbitsColor(const Vec3f& c)
+{
+	Planet::setOrbitColor(c);
+}
+
+Vec3f SolarSystem::getOrbitsColor(void) const
+{
+	return Planet::getOrbitColor();
+}
+
+void SolarSystem::setMajorPlanetsOrbitsColor(const Vec3f &c)
+{
+	Planet::setMajorPlanetOrbitColor(c);
+}
+
+Vec3f SolarSystem::getMajorPlanetsOrbitsColor(void) const
+{
+	return Planet::getMajorPlanetOrbitColor();
+}
+
+void SolarSystem::setMinorPlanetsOrbitsColor(const Vec3f &c)
+{
+	Planet::setMinorPlanetOrbitColor(c);
+}
+
+Vec3f SolarSystem::getMinorPlanetsOrbitsColor(void) const
+{
+	return Planet::getMinorPlanetOrbitColor();
+}
+
+void SolarSystem::setDwarfPlanetsOrbitsColor(const Vec3f &c)
+{
+	Planet::setDwarfPlanetOrbitColor(c);
+}
+
+Vec3f SolarSystem::getDwarfPlanetsOrbitsColor(void) const
+{
+	return Planet::getDwarfPlanetOrbitColor();
+}
+
+void SolarSystem::setMoonsOrbitsColor(const Vec3f &c)
+{
+	Planet::setMoonOrbitColor(c);
+}
+
+Vec3f SolarSystem::getMoonsOrbitsColor(void) const
+{
+	return Planet::getMoonOrbitColor();
+}
+
+void SolarSystem::setCubewanosOrbitsColor(const Vec3f &c)
+{
+	Planet::setCubewanoOrbitColor(c);
+}
+
+Vec3f SolarSystem::getCubewanosOrbitsColor(void) const
+{
+	return Planet::getCubewanoOrbitColor();
+}
+
+void SolarSystem::setPlutinosOrbitsColor(const Vec3f &c)
+{
+	Planet::setPlutinoOrbitColor(c);
+}
+
+Vec3f SolarSystem::getPlutinosOrbitsColor(void) const
+{
+	return Planet::getPlutinoOrbitColor();
+}
+
+void SolarSystem::setScatteredDiskObjectsOrbitsColor(const Vec3f &c)
+{
+	Planet::setScatteredDiscObjectOrbitColor(c);
+}
+
+Vec3f SolarSystem::getScatteredDiskObjectsOrbitsColor(void) const
+{
+	return Planet::getScatteredDiscObjectOrbitColor();
+}
+
+void SolarSystem::setOortCloudObjectsOrbitsColor(const Vec3f &c)
+{
+	Planet::setOortCloudObjectOrbitColor(c);
+}
+
+Vec3f SolarSystem::getOortCloudObjectsOrbitsColor(void) const
+{
+	return Planet::getOortCloudObjectOrbitColor();
+}
+
+void SolarSystem::setCometsOrbitsColor(const Vec3f& c)
+{
+	Planet::setCometOrbitColor(c);
+}
+
+Vec3f SolarSystem::getCometsOrbitsColor(void) const
+{
+	return Planet::getCometOrbitColor();
+}
+
+void SolarSystem::setSednoidsOrbitsColor(const Vec3f& c)
+{
+	Planet::setSednoidOrbitColor(c);
+}
+
+Vec3f SolarSystem::getSednoidsOrbitsColor(void) const
+{
+	return Planet::getSednoidOrbitColor();
+}
+
+void SolarSystem::setMercuryOrbitColor(const Vec3f &c)
+{
+	Planet::setMercuryOrbitColor(c);
+}
+
+Vec3f SolarSystem::getMercuryOrbitColor(void) const
+{
+	return Planet::getMercuryOrbitColor();
+}
+
+void SolarSystem::setVenusOrbitColor(const Vec3f &c)
+{
+	Planet::setVenusOrbitColor(c);
+}
+
+Vec3f SolarSystem::getVenusOrbitColor(void) const
+{
+	return Planet::getVenusOrbitColor();
+}
+
+void SolarSystem::setEarthOrbitColor(const Vec3f &c)
+{
+	Planet::setEarthOrbitColor(c);
+}
+
+Vec3f SolarSystem::getEarthOrbitColor(void) const
+{
+	return Planet::getEarthOrbitColor();
+}
+
+void SolarSystem::setMarsOrbitColor(const Vec3f &c)
+{
+	Planet::setMarsOrbitColor(c);
+}
+
+Vec3f SolarSystem::getMarsOrbitColor(void) const
+{
+	return Planet::getMarsOrbitColor();
+}
+
+void SolarSystem::setJupiterOrbitColor(const Vec3f &c)
+{
+	Planet::setJupiterOrbitColor(c);
+}
+
+Vec3f SolarSystem::getJupiterOrbitColor(void) const
+{
+	return Planet::getJupiterOrbitColor();
+}
+
+void SolarSystem::setSaturnOrbitColor(const Vec3f &c)
+{
+	Planet::setSaturnOrbitColor(c);
+}
+
+Vec3f SolarSystem::getSaturnOrbitColor(void) const
+{
+	return Planet::getSaturnOrbitColor();
+}
+
+void SolarSystem::setUranusOrbitColor(const Vec3f &c)
+{
+	Planet::setUranusOrbitColor(c);
+}
+
+Vec3f SolarSystem::getUranusOrbitColor(void) const
+{
+	return Planet::getUranusOrbitColor();
+}
+
+void SolarSystem::setNeptuneOrbitColor(const Vec3f &c)
+{
+	Planet::setNeptuneOrbitColor(c);
+}
+
+Vec3f SolarSystem::getNeptuneOrbitColor(void) const
+{
+	return Planet::getNeptuneOrbitColor();
+}
 
 // Set/Get if Moon display is scaled
 void SolarSystem::setFlagMoonScale(bool b)
@@ -1719,7 +1949,7 @@ void SolarSystem::reloadPlanets()
 	bool flagHints = getFlagHints();
 	bool flagLabels = getFlagLabels();
 	bool flagOrbits = getFlagOrbits();
-	bool flagNative = getFlagNativeNames();
+	bool flagNative = getFlagNativePlanetNames();
 	bool flagTrans = getFlagTranslatedNames();
 	bool hasSelection = false;
 
@@ -1768,7 +1998,7 @@ void SolarSystem::reloadPlanets()
 
 	// Re-load the ssystem.ini file
 	loadPlanets();	
-	computePositions(StelUtils::getJDFromSystem());
+	computePositions(core->getJDE());
 	setSelected("");
 	recreateTrails();
 	
@@ -1782,7 +2012,7 @@ void SolarSystem::reloadPlanets()
 	setFlagHints(flagHints);
 	setFlagLabels(flagLabels);
 	setFlagOrbits(flagOrbits);
-	setFlagNativeNames(flagNative);
+	setFlagNativePlanetNames(flagNative);
 	setFlagTranslatedNames(flagTrans);
 
 	if (hasSelection)
@@ -1793,6 +2023,8 @@ void SolarSystem::reloadPlanets()
 
 	// Restore translations
 	updateI18n();
+
+	emit solarSystemDataReloaded();
 }
 
 // Set the algorithm for computation of apparent magnitudes for planets in case  observer on the Earth
@@ -1864,6 +2096,34 @@ double SolarSystem::getCustomGrsJD()
 	return Planet::customGrsJD;
 }
 
+void SolarSystem::setOrbitColorStyle(QString style)
+{
+	if (style.toLower()=="groups")
+		Planet::orbitColorStyle = Planet::ocsGroups;
+	else if (style.toLower()=="major_planets")
+		Planet::orbitColorStyle = Planet::ocsMajorPlanets;
+	else
+		Planet::orbitColorStyle = Planet::ocsOneColor;
+}
+
+QString SolarSystem::getOrbitColorStyle() const
+{
+	QString r = "one_color";
+	switch (Planet::orbitColorStyle)
+	{
+		case Planet::ocsOneColor:
+			r = "one_color";
+			break;
+		case Planet::ocsGroups:
+			r = "groups";
+			break;
+		case Planet::ocsMajorPlanets:
+			r = "major_planets";
+			break;
+	}
+	return r;
+}
+
 double SolarSystem::getEclipseFactor(const StelCore* core) const
 {
 	Vec3d Lp = sun->getEclipticPos();
