@@ -24,8 +24,12 @@ THE SOFTWARE.
 #include "de431.hpp"
 #include "jpleph.h"
 #include "StelUtils.hpp"
+#ifndef UNIT_TEST
 #include "StelCore.hpp"
 #include "StelApp.hpp"
+#else
+#include "VecMath.hpp"
+#endif
 
 #ifdef __cplusplus
   extern "C" {
@@ -38,6 +42,10 @@ static Vec3d tempICRF = Vec3d(0,0,0);
 static char nams[JPL_MAX_N_CONSTANTS][6];
 static double vals[JPL_MAX_N_CONSTANTS];
 static double tempXYZ[6];
+#ifdef UNIT_TEST
+// NOTE: Added hook for unit testing
+static const Mat4d matJ2000ToVsop87(Mat4d::xrotation(-23.4392803055555555556*(M_PI/180)) * Mat4d::zrotation(0.0000275*(M_PI/180)));
+#endif
 
 static bool initDone = false;
 
@@ -47,7 +55,9 @@ void InitDE431(const char* filepath)
 
 	if(jpl_init_error_code() != 0)
 	{
+		#ifndef UNIT_TEST
 		StelApp::getInstance().getCore()->setDe431Active(false);
+		#endif
 		qDebug() << "Error "<< jpl_init_error_code() << "at DE431 init:" << jpl_init_error_message();
 	}
 	else
@@ -103,7 +113,11 @@ bool GetDe431Coor(const double jde, const int planet_id, double * xyz, const int
 	}
 
         tempICRF = Vec3d(tempXYZ[0], tempXYZ[1], tempXYZ[2]);
+	#ifdef UNIT_TEST
+	tempECL = matJ2000ToVsop87 * tempICRF;
+	#else
         tempECL = StelCore::matJ2000ToVsop87 * tempICRF;
+	#endif
 
         xyz[0] = tempECL[0];
         xyz[1] = tempECL[1];
