@@ -26,12 +26,18 @@
 #include <QTreeWidgetItem>
 #include <QMap>
 #include <QVector>
+#include <QTimer>
 
 #include "StelDialog.hpp"
 #include "StelCore.hpp"
 #include "Planet.hpp"
+#include "SolarSystem.hpp"
+#include "Nebula.hpp"
+#include "NebulaMgr.hpp"
+#include "StarMgr.hpp"
 
 class Ui_astroCalcDialogForm;
+class QListWidgetItem;
 
 class AstroCalcDialog : public StelDialog
 {
@@ -74,6 +80,9 @@ public:
 	AstroCalcDialog(QObject* parent);
 	virtual ~AstroCalcDialog();
 
+	//! Notify that the application style changed
+	void styleChanged();
+
 	static QVector<Vec3d> EphemerisListJ2000;
 	static QVector<QString> EphemerisListDates;
 	static int DisplayedPositionIndex;
@@ -103,10 +112,21 @@ private slots:
 	void selectCurrentPhenomen(const QModelIndex &modelIndex);
 	void savePhenomena();
 
+	void drawAltVsTimeDiagram();
+	void drawCurrentTimeDiagram();
+	void mouseOverLine(QMouseEvent *event);
+
+	void changePage(QListWidgetItem *current, QListWidgetItem *previous);
+
+	void updateSolarSystemData();
+
 private:
 	class StelCore* core;
 	class SolarSystem* solarSystem;
+	class NebulaMgr* dsoMgr;
+	class StarMgr* starMgr;
 	class StelObjectMgr* objectMgr;
+	QTimer *currentTimeLine;
 
 	//! Update header names for planetary positions table
 	void setPlanetaryPositionsHeaderNames();
@@ -132,19 +152,37 @@ private:
 	//! Populates the drop-down list of major planets.
 	void populateMajorPlanetList();
 	//! Populates the drop-down list of groups of celestial bodies.
-	void populateGroupCelestialBodyList();
+	void populateGroupCelestialBodyList();	
+	//! Prepare graph settings
+	void prepareAxesAndGraph();
 
-	//! Calculation conjuctions and oppositions.
+	//! Calculation conjunctions and oppositions.
 	//! @note Ported from KStars, should be improved, because this feature calculate
 	//! angular separation ("conjunction" defined as equality of right ascension
 	//! of two body) and current solution is not accurate and slow.
-	QMap<double, double> findClosestApproach(PlanetP& object1, PlanetP& object2, double startJD, double stopJD, float maxSeparation, bool opposition);
+	QMap<double, double> findClosestApproach(PlanetP& object1, PlanetP& object2, double startJD, double stopJD, double maxSeparation, bool opposition);
 	double findDistance(double JD, PlanetP object1, PlanetP object2, bool opposition);
 	bool findPrecise(QPair<double, double>* out, PlanetP object1, PlanetP object2, double JD, double step, int prevSign, bool opposition);
 	void fillPhenomenaTable(const QMap<double, double> list, const PlanetP object1, const PlanetP object2, bool opposition);
 
-	QString delimiter;
+	QMap<double, double> findClosestApproach(PlanetP& object1, NebulaP& object2, double startJD, double stopJD, double maxSeparation);
+	double findDistance(double JD, PlanetP object1, NebulaP object2);
+	bool findPrecise(QPair<double, double>* out, PlanetP object1, NebulaP object2, double JD, double step, int prevSign);
+	void fillPhenomenaTable(const QMap<double, double> list, const PlanetP object1, const NebulaP object2);
+
+	QMap<double, double> findClosestApproach(PlanetP& object1, StelObjectP& object2, double startJD, double stopJD, double maxSeparation);
+	double findDistance(double JD, PlanetP object1, StelObjectP object2);
+	bool findPrecise(QPair<double, double>* out, PlanetP object1, StelObjectP object2, double JD, double step, int prevSign);
+	void fillPhenomenaTable(const QMap<double, double> list, const PlanetP object1, const StelObjectP object2);
+
+	QString delimiter, acEndl;
 	QStringList ephemerisHeader, phenomenaHeader, planetaryPositionsHeader;
+	static float brightLimit;
+	static float minY, maxY;
+
+	//! Make sure that no tabs icons are outside of the viewport.
+	//! @todo Limit the width to the width of the screen *available to the window*.
+	void updateTabBarListWidgetWidth();
 };
 
 // Reimplements the QTreeWidgetItem class to fix the sorting bug
