@@ -92,6 +92,12 @@ public:
 	//! Get whether the button toggling nebulae background is visible
 	bool getFlagShowNebulaBackgroundButton() const;
 
+	//! Get whether the button toggling TOAST survey is visible
+	bool getFlagShowToastSurveyButton() const;
+
+	//! Get whether the button toggling bookmarks is visible
+	bool getFlagShowBookmarksButton() const;
+
 	//! returns true if the gui has completed init process.
 	bool initComplete(void) const;
 
@@ -120,6 +126,12 @@ public slots:
 	//! Define whether the button toggling nebulae background should be visible
 	void setFlagShowNebulaBackgroundButton(bool b);
 
+	//! Define whether the button toggling TOAST survey should be visible
+	void setFlagShowToastSurveyButton(bool b);
+
+	//! Define whether the button toggling bookmarks should be visible
+	void setFlagShowBookmarksButton(bool b);
+
 	void setFlagShowDecimalDegrees(bool b);
 
 	//! Get the auto-hide status of the horizontal toolbar.
@@ -206,6 +218,12 @@ private:
 	bool flagShowNebulaBackgroundButton;
 	StelButton* btShowNebulaeBackground;
 
+	bool flagShowToastSurveyButton;
+	StelButton* btShowToastSurvey;
+
+	bool flagShowBookmarksButton;
+	StelButton* btShowBookmarks;
+
 	bool initDone;
 
 	QSizeF savedProgressBarSize;
