@@ -62,6 +62,8 @@
 #include <QSet>
 #include <QStringList>
 #include <QTemporaryFile>
+#include <QTimer>
+#include <QEventLoop>
 
 #include <cmath>
 
@@ -69,8 +71,12 @@ StelMainScriptAPI::StelMainScriptAPI(QObject *parent) : QObject(parent)
 {
 	if(StelSkyLayerMgr* smgr = GETSTELMODULE(StelSkyLayerMgr))
 	{
-		connect(this, SIGNAL(requestLoadSkyImage(const QString&, const QString&, double, double, double, double, double, double, double, double, double, double, bool)), smgr, SLOT(loadSkyImage(const QString&, const QString&, double, double, double, double, double, double, double, double, double, double, bool)));
-		connect(this, SIGNAL(requestLoadSkyImageAltAz(const QString&, const QString&, double, double, double, double, double, double, double, double, double, double, bool)), smgr, SLOT(loadSkyImageAltAz(const QString&, const QString&, double, double, double, double, double, double, double, double, double, double, bool)));
+		connect(this, SIGNAL(requestLoadSkyImage(const QString&, const QString&, double, double, double, double, double, double, double, double, double, double, bool, StelCore::FrameType)),
+			smgr, SLOT(         loadSkyImage(const QString&, const QString&, double, double, double, double, double, double, double, double, double, double, bool, StelCore::FrameType)));
+		// The next is deprecated and should be removed in V0.16.
+		connect(this, SIGNAL(requestLoadSkyImageAltAz(const QString&, const QString&, double, double, double, double, double, double, double, double, double, double, bool)),
+			smgr, SLOT(         loadSkyImageAltAz(const QString&, const QString&, double, double, double, double, double, double, double, double, double, double, bool)));
+
 		connect(this, SIGNAL(requestRemoveSkyImage(const QString&)), smgr, SLOT(removeSkyLayer(const QString&)));
 	}
 
@@ -175,7 +181,7 @@ QString StelMainScriptAPI::getDate(const QString& spec)
 	if (spec=="utc")
 		return StelUtils::julianDayToISO8601String(getJDay());
 	else
-		return StelUtils::julianDayToISO8601String(getJDay()+StelUtils::getGMTShiftFromQT(getJDay())/24);
+		return StelUtils::julianDayToISO8601String(getJDay()+StelApp::getInstance().getCore()->getUTCOffset(getJDay())/24);
 }
 
 QString StelMainScriptAPI::getDeltaT() const
@@ -416,44 +422,64 @@ void StelMainScriptAPI::setViewportStretch(const float stretch)
 }
 
 void StelMainScriptAPI::loadSkyImage(const QString& id, const QString& filename,
-				     double ra0, double dec0,
-				     double ra1, double dec1,
-				     double ra2, double dec2,
-				     double ra3, double dec3,
-				     double minRes, double maxBright, bool visible)
+				     double lon0, double lat0,
+				     double lon1, double lat1,
+				     double lon2, double lat2,
+				     double lon3, double lat3,
+				     double minRes, double maxBright, bool visible, const QString &frame)
 {
 	QString path = "scripts/" + filename;
-	emit(requestLoadSkyImage(id, path, ra0, dec0, ra1, dec1, ra2, dec2, ra3, dec3, minRes, maxBright, visible));
+	StelCore::FrameType frameType=StelCore::FrameJ2000;
+	if (frame=="EqDate")
+		frameType=StelCore::FrameEquinoxEqu;
+	else if (frame=="EclJ2000")
+		frameType=StelCore::FrameObservercentricEclipticJ2000;
+	else if (frame=="EclDate")
+		frameType=StelCore::FrameObservercentricEclipticOfDate;
+	else if (frame.startsWith("Gal"))
+		frameType=StelCore::FrameGalactic;
+	else if (frame.startsWith("SuperG"))
+		frameType=StelCore::FrameSupergalactic;
+	else if (frame=="AzAlt")
+		frameType=StelCore::FrameAltAz;
+	else if (frame!="EqJ2000")
+	{
+		qDebug() << "StelMainScriptAPI::loadSkyImage(): unknown frame type " << frame << " requested -- Using Equatorial J2000";
+	}
+
+	emit(requestLoadSkyImage(id, path, lon0, lat0, lon1, lat1, lon2, lat2, lon3, lat3, minRes, maxBright, visible, frameType));
 }
 
+// Convenience method:
 void StelMainScriptAPI::loadSkyImage(const QString& id, const QString& filename,
-				     const QString& ra0, const QString& dec0,
-				     const QString& ra1, const QString& dec1,
-				     const QString& ra2, const QString& dec2,
-				     const QString& ra3, const QString& dec3,
-				     double minRes, double maxBright, bool visible)
+				     const QString& lon0, const QString& lat0,
+				     const QString& lon1, const QString& lat1,
+				     const QString& lon2, const QString& lat2,
+				     const QString& lon3, const QString& lat3,
+				     double minRes, double maxBright, bool visible, const QString& frame)
 {
 	loadSkyImage(id, filename,
-		     StelUtils::getDecAngle(ra0) *180./M_PI, StelUtils::getDecAngle(dec0)*180./M_PI,
-		     StelUtils::getDecAngle(ra1) *180./M_PI, StelUtils::getDecAngle(dec1)*180./M_PI,
-		     StelUtils::getDecAngle(ra2) *180./M_PI, StelUtils::getDecAngle(dec2)*180./M_PI,
-		     StelUtils::getDecAngle(ra3) *180./M_PI, StelUtils::getDecAngle(dec3)*180./M_PI,
-		     minRes, maxBright, visible);
+		     StelUtils::getDecAngle(lon0) *180./M_PI, StelUtils::getDecAngle(lat0)*180./M_PI,
+		     StelUtils::getDecAngle(lon1) *180./M_PI, StelUtils::getDecAngle(lat1)*180./M_PI,
+		     StelUtils::getDecAngle(lon2) *180./M_PI, StelUtils::getDecAngle(lat2)*180./M_PI,
+		     StelUtils::getDecAngle(lon3) *180./M_PI, StelUtils::getDecAngle(lat3)*180./M_PI,
+		     minRes, maxBright, visible, frame);
 }
 
+// Convenience method: (Fixed 2017-03: rotation increased by 90deg, makes upright images now!)
 void StelMainScriptAPI::loadSkyImage(const QString& id, const QString& filename,
-				     double ra, double dec, double angSize, double rotation,
-				     double minRes, double maxBright, bool visible)
+				     double lon, double lat, double angSize, double rotation,
+				     double minRes, double maxBright, bool visible, const QString &frame)
 {
 	Vec3f XYZ;
-	static const float RADIUS_NEB = 1.;
-	StelUtils::spheToRect(ra*M_PI/180., dec*M_PI/180., XYZ);
+	static const float RADIUS_NEB = 1.f;
+	StelUtils::spheToRect(lon*M_PI/180., lat*M_PI/180., XYZ);
 	XYZ*=RADIUS_NEB;
-	float texSize = RADIUS_NEB * sin(angSize/2/60*M_PI/180);
+	float texSize = RADIUS_NEB * sin(angSize/2./60.*M_PI/180.);
 	Mat4f matPrecomp = Mat4f::translation(XYZ) *
-			   Mat4f::zrotation(ra*M_PI/180.) *
-			   Mat4f::yrotation(-dec*M_PI/180.) *
-			   Mat4f::xrotation(rotation*M_PI/180.);
+			   Mat4f::zrotation(lon*M_PI/180.) *
+			   Mat4f::yrotation(-lat*M_PI/180.) *
+			   Mat4f::xrotation((rotation+90.0)*M_PI/180.);
 
 	Vec3f corners[4];
 	corners[0] = matPrecomp * Vec3f(0.f,-texSize,-texSize);
@@ -471,21 +497,22 @@ void StelMainScriptAPI::loadSkyImage(const QString& id, const QString& filename,
 		     cornersRaDec[1][0]*180./M_PI, cornersRaDec[1][1]*180./M_PI,
 		     cornersRaDec[3][0]*180./M_PI, cornersRaDec[3][1]*180./M_PI,
 		     cornersRaDec[2][0]*180./M_PI, cornersRaDec[2][1]*180./M_PI,
-		     minRes, maxBright, visible);
+		     minRes, maxBright, visible, frame);
 }
 
 
-
+// Convenience method:
 void StelMainScriptAPI::loadSkyImage(const QString& id, const QString& filename,
-				     const QString& ra, const QString& dec,
+				     const QString& lon, const QString& lat,
 				     double angSize, double rotation,
-				     double minRes, double maxBright, bool visible)
+				     double minRes, double maxBright, bool visible, const QString &frame)
 {
-	loadSkyImage(id, filename, StelUtils::getDecAngle(ra)*180./M_PI,
-		     StelUtils::getDecAngle(dec)*180./M_PI, angSize,
-		     rotation, minRes, maxBright, visible);
+	loadSkyImage(id, filename, StelUtils::getDecAngle(lon)*180./M_PI,
+		     StelUtils::getDecAngle(lat)*180./M_PI, angSize,
+		     rotation, minRes, maxBright, visible, frame);
 }
 
+// DEPRECATED with old name
 void StelMainScriptAPI::loadSkyImageAltAz(const QString& id, const QString& filename,
 					  double azi0, double alt0,
 					  double azi1, double alt1,
@@ -493,21 +520,25 @@ void StelMainScriptAPI::loadSkyImageAltAz(const QString& id, const QString& file
 					  double azi3, double alt3,
 					  double minRes, double maxBright, bool visible)
 {
+	qDebug() << "StelMainScriptAPI::loadSkyImageAltAz() is deprecated and will not be available in version 0.16! Please use loadSkyImageAzAlt()";
 	QString path = "scripts/" + filename;
 	emit(requestLoadSkyImageAltAz(id, path, alt0, azi0, alt1, azi1, alt2, azi2, alt3, azi3, minRes, maxBright, visible));
 }
 
+// DEPRECATED with old argument order and name.
 void StelMainScriptAPI::loadSkyImageAltAz(const QString& id, const QString& filename,
 					  double alt, double azi,
 					  double angSize, double rotation,
 					  double minRes, double maxBright, bool visible)
 {
-	Vec3f XYZ;
-	static const float RADIUS_NEB = 1.;
+	qDebug() << "StelMainScriptAPI::loadSkyImageAltAz() is deprecated and will not be available in version 0.16! Please use loadSkyImageAzAlt()";
 
-	StelUtils::spheToRect((180-azi)*M_PI/180., alt*M_PI/180., XYZ);
+	Vec3f XYZ;
+	static const float RADIUS_NEB = 1.0f;
+
+	StelUtils::spheToRect((180.0-azi)*M_PI/180., alt*M_PI/180., XYZ);
 	XYZ*=RADIUS_NEB;
-	float texSize = RADIUS_NEB * sin(angSize/2/60*M_PI/180);
+	float texSize = RADIUS_NEB * sin(angSize/2.0f/60.0f*M_PI/180.0f);
 	Mat4f matPrecomp = Mat4f::translation(XYZ) *
 			   Mat4f::zrotation((180.-azi)*M_PI/180.) *
 			   Mat4f::yrotation(-alt*M_PI/180.) *
@@ -704,12 +735,45 @@ void StelMainScriptAPI::debug(const QString& s)
 	StelApp::getInstance().getScriptMgr().debug(s);
 }
 
-void StelMainScriptAPI::output(const QString &s)
+void StelMainScriptAPI::output(const QString &s) const
 {
 	StelApp::getInstance().getScriptMgr().output(s);
 }
 
-void StelMainScriptAPI::resetOutput(void)
+//! print contents of a QVariantMap
+//! @param map QVariantMap e.g. from getObjectInfo() or getLocationInfo()
+QString StelMainScriptAPI::mapToString(const QVariantMap& map) const
+{
+	QString res = QString("[\n");
+	QList<QVariant::Type> simpleTypeList;
+	simpleTypeList.push_back(QVariant::Bool);
+	simpleTypeList.push_back(QVariant::Int);
+	simpleTypeList.push_back(QVariant::UInt);
+	simpleTypeList.push_back(QVariant::Double);
+
+	QVariantMap::const_iterator i=map.constBegin();
+	while (i != map.constEnd()){
+
+		if (i.value().type()==QMetaType::QString)
+		{
+			res.append(QString("[ \"%1\" = \"%2\" ]\n").arg(i.key()).arg(i.value().toString()));
+		}
+		else if (simpleTypeList.contains(i.value().type()))
+		{
+			res.append(QString("[ \"%1\" = %2 ]\n").arg(i.key()).arg(i.value().toString()));
+		}
+		else
+		{
+			res.append(QString("[ \"%1\" = \"<%2>:%3\" ]\n").arg(i.key()).arg(i.value().typeName()).arg(i.value().toString()));
+		}
+
+		++i;
+	}
+	res.append( QString("]\n"));
+	return res;
+}
+
+void StelMainScriptAPI::resetOutput(void) const
 {
 	StelApp::getInstance().getScriptMgr().resetOutput();
 }
@@ -793,6 +857,31 @@ double StelMainScriptAPI::jdFromDateString(const QString& dt, const QString& spe
 	return StelUtils::getJDFromSystem();
 }
 
+void StelMainScriptAPI::wait(double t) {
+	QEventLoop loop;
+	QTimer timer;
+	timer.setInterval(1000*t);
+	connect(&timer, SIGNAL(timeout()), &loop, SLOT(quit()));
+	timer.start();
+	loop.exec();
+}
+
+void StelMainScriptAPI::waitFor(const QString& dt, const QString& spec)
+{
+	double deltaJD = jdFromDateString(dt, spec) - getJDay();
+	double timeSpeed = getTimeRate();
+	if (timeSpeed == 0.) { qDebug() << "waitFor() called with no time passing - would be infinite. not waiting!"; return;}
+	QEventLoop loop;
+	QTimer timer;
+	int interval=1000*deltaJD*86400/timeSpeed;
+	//qDebug() << "timeSpeed is" << timeSpeed << " interval:" << interval;
+	timer.setInterval(interval);
+	connect(&timer, SIGNAL(timeout()), &loop, SLOT(quit()));
+	timer.start();
+	loop.exec();
+}
+
+
 void StelMainScriptAPI::selectObjectByName(const QString& name, bool pointer)
 {
 	StelObjectMgr* omgr = GETSTELMODULE(StelObjectMgr);
@@ -813,126 +902,8 @@ QVariantMap StelMainScriptAPI::getObjectInfo(const QString& name)
 {
 	StelObjectMgr* omgr = GETSTELMODULE(StelObjectMgr);
 	StelObjectP obj = omgr->searchByName(name);
-	QVariantMap map;
 
-	if (!obj)
-	{
-		debug("getObjectData WARNING - object not found: " + name);
-		map.insert("found", false);
-		return map;
-	}
-	else
-	{
-		map.insert("found", true);
-	}
-
-	
-	Vec3d pos;
-	double ra, dec, alt, az, glong, glat;
-	StelCore* core = StelApp::getInstance().getCore();
-	bool useOldAzimuth = StelApp::getInstance().getFlagSouthAzimuthUsage();
-
-	// ra/dec
-	pos = obj->getEquinoxEquatorialPos(core);
-	StelUtils::rectToSphe(&ra, &dec, pos);
-	map.insert("ra", ra*180./M_PI);
-	map.insert("dec", dec*180./M_PI);	
-
-	// ra/dec in J2000
-	pos = obj->getJ2000EquatorialPos(core);
-	StelUtils::rectToSphe(&ra, &dec, pos);
-	map.insert("raJ2000", ra*180./M_PI);
-	map.insert("decJ2000", dec*180./M_PI);	
-
-	// apparent altitude/azimuth
-	pos = obj->getAltAzPosApparent(core);
-	StelUtils::rectToSphe(&az, &alt, pos);
-	float direction = 3.; // N is zero, E is 90 degrees
-	if (useOldAzimuth)
-		direction = 2.;
-	az = direction*M_PI - az;
-	if (az > M_PI*2)
-		az -= M_PI*2;
-
-	map.insert("altitude", alt*180./M_PI);
-	map.insert("azimuth", az*180./M_PI);	
-
-	// geometric altitude/azimuth
-	pos = obj->getAltAzPosGeometric(core);
-	StelUtils::rectToSphe(&az, &alt, pos);
-	az = direction*M_PI - az;
-	if (az > M_PI*2)
-		az -= M_PI*2;
-
-	map.insert("altitude-geometric", alt*180./M_PI);
-	map.insert("azimuth-geometric", az*180./M_PI);	
-
-	// galactic long/lat
-	pos = obj->getGalacticPos(core);
-	StelUtils::rectToSphe(&glong, &glat, pos);
-	map.insert("glong", glong*180./M_PI);
-	map.insert("glat", glat*180./M_PI);	
-
-	if (core->getCurrentLocation().planetName == "Earth")
-	{
-		SolarSystem* ssmgr = GETSTELMODULE(SolarSystem);
-		double ra_equ, dec_equ, lambda, beta;
-		// J2000
-		double eclJ2000 = ssmgr->getEarth()->getRotObliquity(2451545.0);
-		double ecl = ssmgr->getEarth()->getRotObliquity(core->getJDE());
-
-		// ecliptic longitude/latitude (J2000 frame)
-		StelUtils::rectToSphe(&ra_equ,&dec_equ, obj->getJ2000EquatorialPos(core));
-		StelUtils::equToEcl(ra_equ, dec_equ, eclJ2000, &lambda, &beta);
-		if (lambda<0) lambda+=2.0*M_PI;
-		map.insert("elongJ2000", lambda*180./M_PI);
-		map.insert("elatJ2000", beta*180./M_PI);
-
-		// ecliptic longitude/latitude
-		StelUtils::rectToSphe(&ra_equ,&dec_equ, obj->getEquinoxEquatorialPos(core));
-		StelUtils::equToEcl(ra_equ, dec_equ, ecl, &lambda, &beta);
-		if (lambda<0) lambda+=2.0*M_PI;
-		map.insert("elong", lambda*180./M_PI);
-		map.insert("elat", beta*180./M_PI);
-	}
-
-	// magnitude
-	map.insert("vmag", obj->getVMagnitude(core));
-	map.insert("vmage", obj->getVMagnitudeWithExtinction(core));
-
-	// angular size
-	double angularSize = 2.*obj->getAngularSize(core)*M_PI/180.;
-	bool sign;
-	double deg;
-	StelUtils::radToDecDeg(angularSize, sign, deg);
-	if (!sign)
-		deg *= -1;
-	map.insert("size", angularSize);
-	map.insert("size-dd", deg);
-	map.insert("size-deg", StelUtils::radToDecDegStr(angularSize, 5));
-	map.insert("size-dms", StelUtils::radToDmsStr(angularSize, true));
-
-	if (obj->getType().toLower()=="planet" && name!="Sun")
-	{
-		SolarSystem* ssmgr = GETSTELMODULE(SolarSystem);
-		map.insert("distance", obj->getJ2000EquatorialPos(core).length());
-		double phase = ssmgr->getPhaseForPlanet(name);
-		map.insert("phase", phase);
-		map.insert("illumination", 100.*phase);
-		double phaseAngle = ssmgr->getPhaseAngleForPlanet(name);
-		map.insert("phase-angle", phaseAngle);
-		map.insert("phase-angle-dms", StelUtils::radToDmsStr(phaseAngle));
-		map.insert("phase-angle-deg", StelUtils::radToDecDegStr(phaseAngle));
-		double elongation = ssmgr->getElongationForPlanet(name);
-		map.insert("elongation", elongation);
-		map.insert("elongation-dms", StelUtils::radToDmsStr(elongation));
-		map.insert("elongation-deg", StelUtils::radToDecDegStr(elongation));
-	}
-
-	// localized name
-	map.insert("localized-name", obj->getNameI18n());
-
-	return map;
+	return StelObjectMgr::getObjectInfo(obj);
 }
 
 QVariantMap StelMainScriptAPI::getSelectedObjectInfo()
@@ -948,128 +919,9 @@ QVariantMap StelMainScriptAPI::getSelectedObjectInfo()
 
 	StelObjectP obj = omgr->getSelectedObject()[0];
 
-	if (!obj)
-	{
-		debug("getObjectData WARNING - object not found");
-		map.insert("found", false);
-		return map;
-	}
-	else
-	{
-		map.insert("found", true);
-	}
-
-	// OK, object found. Let's go.
-	Vec3d pos;
-	double ra, dec, alt, az, glong, glat;
-	StelCore* core = StelApp::getInstance().getCore();
-	bool useOldAzimuth = StelApp::getInstance().getFlagSouthAzimuthUsage();
-
-	// ra/dec
-	pos = obj->getEquinoxEquatorialPos(core);
-	StelUtils::rectToSphe(&ra, &dec, pos);
-	map.insert("ra", ra*180./M_PI);
-	map.insert("dec", dec*180./M_PI);	
-
-	// ra/dec in J2000
-	pos = obj->getJ2000EquatorialPos(core);
-	StelUtils::rectToSphe(&ra, &dec, pos);
-	map.insert("raJ2000", ra*180./M_PI);
-	map.insert("decJ2000", dec*180./M_PI);	
-
-	// apparent altitude/azimuth
-	pos = obj->getAltAzPosApparent(core);
-	StelUtils::rectToSphe(&az, &alt, pos);
-	float direction = 3.; // N is zero, E is 90 degrees
-	if (useOldAzimuth)
-		direction = 2.;
-	az = direction*M_PI - az;
-	if (az > M_PI*2)
-		az -= M_PI*2;
-
-	map.insert("altitude", alt*180./M_PI);
-	map.insert("azimuth", az*180./M_PI);	
-
-	// geometric altitude/azimuth
-	pos = obj->getAltAzPosGeometric(core);
-	StelUtils::rectToSphe(&az, &alt, pos);
-	az = direction*M_PI - az;
-	if (az > M_PI*2)
-		az -= M_PI*2;
-
-	map.insert("altitude-geometric", alt*180./M_PI);
-	map.insert("azimuth-geometric", az*180./M_PI);	
-
-	// galactic long/lat
-	pos = obj->getGalacticPos(core);
-	StelUtils::rectToSphe(&glong, &glat, pos);
-	map.insert("glong", glong*180./M_PI);
-	map.insert("glat", glat*180./M_PI);
-
-	if (core->getCurrentLocation().planetName == "Earth")
-	{
-		SolarSystem* ssmgr = GETSTELMODULE(SolarSystem);
-		double ra_equ, dec_equ, lambda, beta;
-		// J2000
-		double eclJ2000 = ssmgr->getEarth()->getRotObliquity(2451545.0);
-		double ecl = ssmgr->getEarth()->getRotObliquity(core->getJDE());
-
-		// ecliptic longitude/latitude (J2000 frame)
-		StelUtils::rectToSphe(&ra_equ,&dec_equ, obj->getJ2000EquatorialPos(core));
-		StelUtils::equToEcl(ra_equ, dec_equ, eclJ2000, &lambda, &beta);
-		if (lambda<0) lambda+=2.0*M_PI;
-		map.insert("elongJ2000", lambda*180./M_PI);
-		map.insert("elatJ2000", beta*180./M_PI);
-
-		// ecliptic longitude/latitude
-		StelUtils::rectToSphe(&ra_equ,&dec_equ, obj->getEquinoxEquatorialPos(core));
-		StelUtils::equToEcl(ra_equ, dec_equ, ecl, &lambda, &beta);
-		if (lambda<0) lambda+=2.0*M_PI;
-		map.insert("elong", lambda*180./M_PI);
-		map.insert("elat", beta*180./M_PI);
-	}
-
-	// magnitude
-	map.insert("vmag", obj->getVMagnitude(core));
-	map.insert("vmage", obj->getVMagnitudeWithExtinction(core));
-
-	// angular size
-	double angularSize = 2.*obj->getAngularSize(core)*M_PI/180.;
-	bool sign;
-	double deg;
-	StelUtils::radToDecDeg(angularSize, sign, deg);
-	if (!sign)
-		deg *= -1;
-	map.insert("size", angularSize);
-	map.insert("size-dd", deg);
-	map.insert("size-deg", StelUtils::radToDecDegStr(angularSize, 5));
-	map.insert("size-dms", StelUtils::radToDmsStr(angularSize, true));
-
-	if (obj->getType().toLower()=="planet" && obj->getEnglishName()!="Sun")
-	{
-		SolarSystem* ssmgr = GETSTELMODULE(SolarSystem);
-		map.insert("distance", obj->getJ2000EquatorialPos(core).length());
-		double phase = ssmgr->getPhaseForPlanet(obj->getEnglishName());
-		map.insert("phase", phase);
-		map.insert("illumination", 100.*phase);
-		double phaseAngle = ssmgr->getPhaseAngleForPlanet(obj->getEnglishName());
-		map.insert("phase-angle", phaseAngle);
-		map.insert("phase-angle-dms", StelUtils::radToDmsStr(phaseAngle));
-		map.insert("phase-angle-deg", StelUtils::radToDecDegStr(phaseAngle));
-		double elongation = ssmgr->getElongationForPlanet(obj->getEnglishName());
-		map.insert("elongation", elongation);
-		map.insert("elongation-dms", StelUtils::radToDmsStr(elongation));
-		map.insert("elongation-deg", StelUtils::radToDecDegStr(elongation));
-	}
-
-	// english name or designation & localized name
-	map.insert("name", obj->getEnglishName());
-	map.insert("localized-name", obj->getNameI18n());
-
-	return map;
+	return StelObjectMgr::getObjectInfo(obj);
 }
 
-
 void StelMainScriptAPI::clear(const QString& state)
 {
 	LandscapeMgr* lmgr = GETSTELMODULE(LandscapeMgr);
@@ -1096,8 +948,11 @@ void StelMainScriptAPI::clear(const QString& state)
 		mmgr->setZHR(10);
 		glmgr->setFlagAzimuthalGrid(false);
 		glmgr->setFlagGalacticGrid(false);
+		glmgr->setFlagSupergalacticGrid(false);
 		glmgr->setFlagEquatorGrid(false);
+		glmgr->setFlagEquatorJ2000Grid(false);
 		glmgr->setFlagEquatorLine(false);
+		glmgr->setFlagEquatorJ2000Line(false);
 		glmgr->setFlagEclipticLine(false);
 		glmgr->setFlagEclipticJ2000Line(false);
 		glmgr->setFlagMeridianLine(false);
@@ -1106,9 +961,20 @@ void StelMainScriptAPI::clear(const QString& state)
 		glmgr->setFlagColureLines(false);
 		glmgr->setFlagPrimeVerticalLine(false);
 		glmgr->setFlagGalacticEquatorLine(false);
-		glmgr->setFlagEquatorJ2000Grid(false);
+		glmgr->setFlagSupergalacticEquatorLine(false);
+		glmgr->setFlagCircumpolarCircles(false);
+		glmgr->setFlagLongitudeLine(false);
 		glmgr->setFlagEclipticGrid(false);
 		glmgr->setFlagEclipticJ2000Grid(false);
+		glmgr->setFlagCelestialJ2000Poles(false);
+		glmgr->setFlagCelestialPoles(false);
+		glmgr->setFlagZenithNadir(false);
+		glmgr->setFlagEclipticJ2000Poles(false);
+		glmgr->setFlagEclipticPoles(false);
+		glmgr->setFlagGalacticPoles(false);
+		glmgr->setFlagSupergalacticPoles(false);
+		glmgr->setFlagEquinoxJ2000Points(false);
+		glmgr->setFlagEquinoxPoints(false);
 		lmgr->setFlagCardinalsPoints(false);
 		cmgr->setFlagLines(false);
 		cmgr->setFlagLabels(false);
@@ -1135,14 +1001,28 @@ void StelMainScriptAPI::clear(const QString& state)
 		mmgr->setZHR(0);
 		glmgr->setFlagAzimuthalGrid(false);
 		glmgr->setFlagGalacticGrid(false);
+		glmgr->setFlagSupergalacticGrid(false);
 		glmgr->setFlagEquatorGrid(true);
+		glmgr->setFlagEquatorJ2000Grid(false);
 		glmgr->setFlagEquatorLine(false);
+		glmgr->setFlagEquatorJ2000Line(false);
 		glmgr->setFlagEclipticLine(false);
 		glmgr->setFlagMeridianLine(false);
 		glmgr->setFlagLongitudeLine(false);
 		glmgr->setFlagHorizonLine(false);
 		glmgr->setFlagGalacticEquatorLine(false);
-		glmgr->setFlagEquatorJ2000Grid(false);
+		glmgr->setFlagSupergalacticEquatorLine(false);
+		glmgr->setFlagCircumpolarCircles(false);
+		glmgr->setFlagLongitudeLine(false);
+		glmgr->setFlagCelestialJ2000Poles(false);
+		glmgr->setFlagCelestialPoles(false);
+		glmgr->setFlagZenithNadir(false);
+		glmgr->setFlagEclipticJ2000Poles(false);
+		glmgr->setFlagEclipticPoles(false);
+		glmgr->setFlagGalacticPoles(false);
+		glmgr->setFlagSupergalacticPoles(false);
+		glmgr->setFlagEquinoxJ2000Points(false);
+		glmgr->setFlagEquinoxPoints(false);
 		lmgr->setFlagCardinalsPoints(false);
 		cmgr->setFlagLines(true);
 		cmgr->setFlagLabels(true);
@@ -1169,14 +1049,28 @@ void StelMainScriptAPI::clear(const QString& state)
 		mmgr->setZHR(0);
 		glmgr->setFlagAzimuthalGrid(false);
 		glmgr->setFlagGalacticGrid(false);
+		glmgr->setFlagSupergalacticGrid(false);
 		glmgr->setFlagEquatorGrid(false);
+		glmgr->setFlagEquatorJ2000Grid(false);
 		glmgr->setFlagEquatorLine(false);
+		glmgr->setFlagEquatorJ2000Line(false);
 		glmgr->setFlagEclipticLine(false);
 		glmgr->setFlagMeridianLine(false);
 		glmgr->setFlagLongitudeLine(false);
 		glmgr->setFlagHorizonLine(false);
 		glmgr->setFlagGalacticEquatorLine(false);
-		glmgr->setFlagEquatorJ2000Grid(false);
+		glmgr->setFlagSupergalacticEquatorLine(false);
+		glmgr->setFlagCircumpolarCircles(false);
+		glmgr->setFlagLongitudeLine(false);
+		glmgr->setFlagCelestialJ2000Poles(false);
+		glmgr->setFlagCelestialPoles(false);
+		glmgr->setFlagZenithNadir(false);
+		glmgr->setFlagEclipticJ2000Poles(false);
+		glmgr->setFlagEclipticPoles(false);
+		glmgr->setFlagGalacticPoles(false);
+		glmgr->setFlagSupergalacticPoles(false);
+		glmgr->setFlagEquinoxJ2000Points(false);
+		glmgr->setFlagEquinoxPoints(false);
 		lmgr->setFlagCardinalsPoints(false);
 		cmgr->setFlagLines(false);
 		cmgr->setFlagLabels(false);
@@ -1202,15 +1096,29 @@ void StelMainScriptAPI::clear(const QString& state)
 		ssmgr->setFlagTrails(false);
 		mmgr->setZHR(0);
 		glmgr->setFlagAzimuthalGrid(false);
-		glmgr->setFlagGalacticGrid(false);
+		glmgr->setFlagGalacticGrid(true);
+		glmgr->setFlagSupergalacticGrid(false);
 		glmgr->setFlagEquatorGrid(false);
+		glmgr->setFlagEquatorJ2000Grid(false);
 		glmgr->setFlagEquatorLine(false);
+		glmgr->setFlagEquatorJ2000Line(false);
 		glmgr->setFlagEclipticLine(false);
 		glmgr->setFlagMeridianLine(false);
 		glmgr->setFlagLongitudeLine(false);
 		glmgr->setFlagHorizonLine(false);
 		glmgr->setFlagGalacticEquatorLine(false);
-		glmgr->setFlagEquatorJ2000Grid(false);
+		glmgr->setFlagSupergalacticEquatorLine(false);
+		glmgr->setFlagCircumpolarCircles(false);
+		glmgr->setFlagLongitudeLine(false);
+		glmgr->setFlagCelestialJ2000Poles(false);
+		glmgr->setFlagCelestialPoles(false);
+		glmgr->setFlagZenithNadir(false);
+		glmgr->setFlagEclipticJ2000Poles(false);
+		glmgr->setFlagEclipticPoles(false);
+		glmgr->setFlagGalacticPoles(false);
+		glmgr->setFlagSupergalacticPoles(false);
+		glmgr->setFlagEquinoxJ2000Points(false);
+		glmgr->setFlagEquinoxPoints(false);
 		lmgr->setFlagCardinalsPoints(false);
 		cmgr->setFlagLines(false);
 		cmgr->setFlagLabels(false);
@@ -1224,6 +1132,55 @@ void StelMainScriptAPI::clear(const QString& state)
 		lmgr->setFlagFog(false);
 		zl->setFlagShow(false);
 	}
+	else if (state.toLower() == "supergalactic")
+	{
+		movmgr->setMountMode(StelMovementMgr::MountSupergalactic);
+		skyd->setFlagTwinkle(false);
+		skyd->setFlagLuminanceAdaptation(false);
+		ssmgr->setFlagPlanets(false);
+		ssmgr->setFlagHints(false);
+		ssmgr->setFlagOrbits(false);
+		ssmgr->setFlagMoonScale(false);
+		ssmgr->setFlagTrails(false);
+		mmgr->setZHR(0);
+		glmgr->setFlagAzimuthalGrid(false);
+		glmgr->setFlagGalacticGrid(false);
+		glmgr->setFlagSupergalacticGrid(true);
+		glmgr->setFlagEquatorGrid(false);
+		glmgr->setFlagEquatorJ2000Grid(false);
+		glmgr->setFlagEquatorLine(false);
+		glmgr->setFlagEquatorJ2000Line(false);
+		glmgr->setFlagEclipticLine(false);
+		glmgr->setFlagMeridianLine(false);
+		glmgr->setFlagLongitudeLine(false);
+		glmgr->setFlagHorizonLine(false);
+		glmgr->setFlagGalacticEquatorLine(false);
+		glmgr->setFlagSupergalacticEquatorLine(false);
+		glmgr->setFlagCircumpolarCircles(false);
+		glmgr->setFlagLongitudeLine(false);
+		glmgr->setFlagCelestialJ2000Poles(false);
+		glmgr->setFlagCelestialPoles(false);
+		glmgr->setFlagZenithNadir(false);
+		glmgr->setFlagEclipticJ2000Poles(false);
+		glmgr->setFlagEclipticPoles(false);
+		glmgr->setFlagGalacticPoles(false);
+		glmgr->setFlagSupergalacticPoles(false);
+		glmgr->setFlagEquinoxJ2000Points(false);
+		glmgr->setFlagEquinoxPoints(false);
+		lmgr->setFlagCardinalsPoints(false);
+		cmgr->setFlagLines(false);
+		cmgr->setFlagLabels(false);
+		cmgr->setFlagBoundaries(false);
+		cmgr->setFlagArt(false);
+		smgr->setFlagLabels(false);
+		ssmgr->setFlagLabels(false);
+		nmgr->setFlagHints(false);
+		lmgr->setFlagLandscape(false);
+		lmgr->setFlagAtmosphere(false);
+		lmgr->setFlagFog(false);
+		zl->setFlagShow(false);
+	}
+
 	else
 	{
 		qWarning() << "WARNING clear(" << state << ") - state not known";
@@ -1251,7 +1208,7 @@ double StelMainScriptAPI::getViewAzimuthAngle()
 
 double StelMainScriptAPI::getViewRaAngle()
 {
-	const Vec3d& current = StelApp::getInstance().getCore()->j2000ToEquinoxEqu(GETSTELMODULE(StelMovementMgr)->getViewDirectionJ2000());
+	const Vec3d& current = StelApp::getInstance().getCore()->j2000ToEquinoxEqu(GETSTELMODULE(StelMovementMgr)->getViewDirectionJ2000(), StelCore::RefractionOff);
 	double ra, dec;
 	StelUtils::rectToSphe(&ra, &dec, current);
 	// returned RA angle is in range -PI .. PI, but we want 0 .. 360
@@ -1260,7 +1217,7 @@ double StelMainScriptAPI::getViewRaAngle()
 
 double StelMainScriptAPI::getViewDecAngle()
 {
-	const Vec3d& current = StelApp::getInstance().getCore()->j2000ToEquinoxEqu(GETSTELMODULE(StelMovementMgr)->getViewDirectionJ2000());
+	const Vec3d& current = StelApp::getInstance().getCore()->j2000ToEquinoxEqu(GETSTELMODULE(StelMovementMgr)->getViewDirectionJ2000(), StelCore::RefractionOff);
 	double ra, dec;
 	StelUtils::rectToSphe(&ra, &dec, current);
 	return dec*180/M_PI; // convert to degrees from radians
@@ -1327,11 +1284,11 @@ void StelMainScriptAPI::moveToRaDec(const QString& ra, const QString& dec, float
 	StelMovementMgr::MountMode mountMode=mvmgr->getMountMode();
 	Vec3d aimUp;
 	if ( (mountMode==StelMovementMgr::MountEquinoxEquatorial) && (fabs(dDec)> (0.9*M_PI/2.0)) )
-		aimUp=core->equinoxEquToJ2000(Vec3d(-cos(dRa), -sin(dRa), 0.) * (dDec>0. ? 1. : -1. ));
+		aimUp=core->equinoxEquToJ2000(Vec3d(-cos(dRa), -sin(dRa), 0.) * (dDec>0. ? 1. : -1. ), StelCore::RefractionOff);
 	else
-		aimUp=core->equinoxEquToJ2000(Vec3d(0., 0., 1.));
+		aimUp=core->equinoxEquToJ2000(Vec3d(0., 0., 1.), StelCore::RefractionOff);
 
-	mvmgr->moveToJ2000(StelApp::getInstance().getCore()->equinoxEquToJ2000(aim), aimUp, duration);
+	mvmgr->moveToJ2000(StelApp::getInstance().getCore()->equinoxEquToJ2000(aim, StelCore::RefractionOff), aimUp, duration);
 }
 
 void StelMainScriptAPI::moveToRaDecJ2000(const QString& ra, const QString& dec, float duration)
@@ -1357,7 +1314,7 @@ void StelMainScriptAPI::moveToRaDecJ2000(const QString& ra, const QString& dec,
 	mvmgr->moveToJ2000(aimJ2000, aimUp, duration);
 }
 
-QString StelMainScriptAPI::getAppLanguage()
+QString StelMainScriptAPI::getAppLanguage() const
 {
 	return StelApp::getInstance().getLocaleMgr().getAppLanguage();
 }
@@ -1367,7 +1324,7 @@ void StelMainScriptAPI::setAppLanguage(QString langCode)
 	StelApp::getInstance().getLocaleMgr().setAppLanguage(langCode);
 }
 
-QString StelMainScriptAPI::getSkyLanguage()
+QString StelMainScriptAPI::getSkyLanguage() const
 {
 	return StelApp::getInstance().getLocaleMgr().getSkyLanguage();
 }
@@ -1392,7 +1349,7 @@ void StelMainScriptAPI::setMilkyWayIntensity(double i)
 	GETSTELMODULE(MilkyWay)->setIntensity(i);
 }
 
-double StelMainScriptAPI::getMilkyWayIntensity()
+double StelMainScriptAPI::getMilkyWayIntensity() const
 {
 	return GETSTELMODULE(MilkyWay)->getIntensity();
 }
@@ -1407,7 +1364,7 @@ void StelMainScriptAPI::setZodiacalLightIntensity(double i)
 	GETSTELMODULE(ZodiacalLight)->setIntensity(i);
 }
 
-double StelMainScriptAPI::getZodiacalLightIntensity()
+double StelMainScriptAPI::getZodiacalLightIntensity() const
 {
 	return GETSTELMODULE(ZodiacalLight)->getIntensity();
 }
